@@ -6,7 +6,7 @@
 //         
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2019 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -49,7 +49,6 @@ CegoAVLIndexCursor::~CegoAVLIndexCursor()
 
 bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 {
-
     if ( fl.isEmpty() )
     {
 	throw Exception(EXLOC, "Empty field list");
@@ -71,7 +70,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 	pC->abort();
 	delete pC;
 	
-	_rootPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _rdp, _cachedPointer, _cachedLen);	
+	_pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _rdp, _cachedPointer, _cachedLen, _rootPage);	
              
 	_cursorCached = true;
 
@@ -79,7 +78,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 
     // cout << "Read Locking " << _rdp.getFileId() << " " << _rdp.getPageId()  << endl;
     if ( _lockId == 0 )
-	_lockId = _pTM->getLockHandler()->lockData(CegoObject::BTREE, _rdp.getFileId(), _rdp.getPageId(), CegoLockHandler::READ);
+	_lockId = _pTM->getLockHandler()->lockData(CegoObject::BTREE, _rdp.getPageId(), CegoLockHandler::READ);
 	
     
     // get root entry
@@ -124,7 +123,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 	{
 	    // go to the beginning
 
-	    _currentPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len);
+	    _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 	    
 	    _ie.setPtr(p, len);
 	    
@@ -135,7 +134,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 		_idp = _ie.getLeftBranch();		
 
 		_pTM->releaseDataPtrUnlocked(_currentPage, false);
-		_currentPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len);
+		_pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 		
 		_ie.setPtr(p, len);
 	    }
@@ -160,7 +159,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 
 	    // go to the smallest leaf
 
-	    _currentPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len);  
+	    _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);  
 
 	    _ie.setPtr(p, len);
 	    
@@ -201,7 +200,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 		else if ( ! found )
 		{
 		    _idp = idp;
-		    _currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, idp, p, len);
+		    _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, idp, p, len, _currentPage);
 		    _ie.setPtr(p, len);
 		}
 	    }
@@ -213,7 +212,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 	    
 	    // go to the smallest leaf
 
-	    _currentPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len); 
+	    _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage); 
 
 	    _ie.setPtr(p, len);
 
@@ -252,7 +251,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 		else if ( ! found )
 		{
 		    _idp = idp;
-		    _currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, idp, p, len);		    
+		    _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, idp, p, len, _currentPage);
 		    _ie.setPtr(p, len);
 
 		}
@@ -266,14 +265,14 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
     {
 	// go to the beginning
 	
-	_currentPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len);
+	_pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 	
 	_ie.setPtr(p, len);
 	
 	while ( _ie.getLeftBranch() != nil)
 	{	    
 	    _idp = _ie.getLeftBranch();			   
-	    _currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len);	    
+	    _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 	    _ie.setPtr(p, len);
 	}
 	    	
@@ -291,7 +290,7 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 
 
 	_pTM->releaseDataPtrUnlocked(_dataPage, false);
-	_dataPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, dp, p, len);
+	_pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, dp, p, len, _dataPage);
 	
 	// skipping tid
 	
@@ -308,11 +307,10 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 	{
 	    if ( _ignoreTouched )
 	    {			
-		if ( ts == INSERTED 
+		if ( ts == CegoTupleState::INSERTED 
 		     && tid == _pTM->getTID(_tabSetId) 
 		     && tastep < _pTM->getTAStep(_tabSetId) )
 		{
-		    CegoTupleState ts;
 		    _qh.decodeFVL(fl, tp, tlen);
 		    return true;   
 		}
@@ -325,10 +323,10 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 	    {
 		
 		if ( ( _readUncommitted == true 
-		       && ts == INSERTED )
+		       && ts == CegoTupleState::INSERTED )
 		     || ( _readUncommitted == false 
-			  && (( ts == INSERTED && tid == _pTM->getTID(_tabSetId)) 
-			      || ( ts == DELETED && tid != _pTM->getTID(_tabSetId)))))
+			  && (( ts == CegoTupleState::INSERTED && tid == _pTM->getTID(_tabSetId)) 
+			      || ( ts == CegoTupleState::DELETED && tid != _pTM->getTID(_tabSetId)))))
 		{
 		    _qh.decodeFVL(fl, tp, tlen);
 		    return true;   
@@ -350,7 +348,6 @@ bool CegoAVLIndexCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 
 bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 {
-
     if ( _eoc )
 	return false;
 
@@ -377,15 +374,14 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 	{
 	    
 	    _idp = _ie.getRightBranch();	   
-	    _currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len);
-
+	    _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 	    
 	    _ie.setPtr(p, len);
 	    
 	    while ( _ie.getLeftBranch() != nil)
 	    {
 		_idp = _ie.getLeftBranch();		
-		_currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len);		
+		_pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 		_ie.setPtr(p, len);
 	    }	
 	}
@@ -404,7 +400,7 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 	    
 	    CegoDataPointer pdp = _ie.getParent();
 	    
-	    _currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, pdp, p, len);			    
+	    _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, pdp, p, len, _currentPage);
 
 	    _ie.setPtr(p, len);
 	    
@@ -432,13 +428,13 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 			{
 			    
 			    _idp = _ie.getRightBranch();			    
-			    _currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len);	    
+			    _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage);
 			    _ie.setPtr(p, len);
 			    
 			    while ( _ie.getLeftBranch() != nil)
 			    {				
 				_idp = _ie.getLeftBranch();
-				_currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len); 
+				_pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, _idp, p, len, _currentPage); 
 				_ie.setPtr(p, len);
 			    }
 			    entryFound = true;
@@ -449,7 +445,7 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 			_idp = pdp;
 			
 			pdp = _ie.getParent();
-			_currentPage = _pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, pdp, p, len);	    			
+			_pTM->releaseAndClaimDataPtrUnlocked(_currentPage, false, _tabSetId, CegoBufferPool::SYNC, pdp, p, len, _currentPage);
 			_ie.setPtr(p, len);			
 		    }
 		}
@@ -478,7 +474,11 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		case EQUAL:
 		    attrMatch=true;
 		    break;
-		default:
+		case LESS_THAN:
+		case MORE_THAN:
+		case LESS_EQUAL_THAN:
+		case MORE_EQUAL_THAN:
+		case NOT_EQUAL:
 		    break;
 		}
 		break;
@@ -495,7 +495,9 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		    break;
 		case EQUAL:
 		    return getNext(fl, dp);
-		default:
+		case LESS_EQUAL_THAN:
+		case MORE_EQUAL_THAN:
+		case NOT_EQUAL:		    
 		    break;
 		}
 		break;
@@ -507,7 +509,11 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		case LESS_THAN:
 		    attrMatch=true;
 		    break;
-		default:
+		case EQUAL:
+		case MORE_THAN:
+		case LESS_EQUAL_THAN:
+		case MORE_EQUAL_THAN:
+		case NOT_EQUAL:		    		    
 		    break;
 		}
 		break;
@@ -519,7 +525,11 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		case MORE_THAN:
 		    attrMatch=true;
 		    break;
-		default:
+		case EQUAL:
+		case LESS_THAN:
+		case LESS_EQUAL_THAN:
+		case MORE_EQUAL_THAN:
+		case NOT_EQUAL:	
 		    break;		
 		}	
 		break;       
@@ -534,7 +544,10 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		case LESS_THAN:
 		    attrMatch=true;
 		    break;
-		default:
+		case MORE_THAN:
+		case LESS_EQUAL_THAN:
+		case MORE_EQUAL_THAN:
+		case NOT_EQUAL:
 		    break;
 		}
 		break;
@@ -550,7 +563,10 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		case MORE_THAN:
 		    attrMatch=true;
 		    break;
-		default:
+		case LESS_THAN:
+		case LESS_EQUAL_THAN:
+		case MORE_EQUAL_THAN:
+		case NOT_EQUAL:
 		    break;
 		}
 		break;
@@ -571,7 +587,7 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 	    dp = _ie.getData();
 	    
 	    _pTM->releaseDataPtrUnlocked(_dataPage, false);
-	    _dataPage = _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, dp, p, len);
+	    _pTM->claimDataPtrUnlocked(_tabSetId, CegoBufferPool::SYNC, dp, p, len, _dataPage);
 	    
 	    // skipping tid
 	    
@@ -588,7 +604,7 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 	    {
 		if ( _ignoreTouched == true )
 		{
-		    if ( ts == INSERTED 
+		    if ( ts == CegoTupleState::INSERTED 
 			 && tid == _pTM->getTID(_tabSetId) 
 			 && tastep < _pTM->getTAStep(_tabSetId) )
 		    {
@@ -604,10 +620,10 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 		{
 
 		    if ( ( _readUncommitted == true 
-			   && ts == INSERTED )
+			   && ts == CegoTupleState::INSERTED )
 			 || ( _readUncommitted == false 
-			      && (( ts == INSERTED && tid == _pTM->getTID(_tabSetId)) 
-				  || ( ts == DELETED && tid != _pTM->getTID(_tabSetId)))))
+			      && (( ts == CegoTupleState::INSERTED && tid == _pTM->getTID(_tabSetId)) 
+				  || ( ts == CegoTupleState::DELETED && tid != _pTM->getTID(_tabSetId)))))
 		    {
 			_qh.decodeFVL(fl, tp, tlen);
 			return true;
@@ -634,8 +650,7 @@ bool CegoAVLIndexCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 }
 
 void CegoAVLIndexCursor::abort()
-{
-    
+{    
     _pTM->releaseDataPtrUnlocked(_currentPage, false);
     _currentPage = CegoBufferPage();
     
@@ -647,7 +662,6 @@ void CegoAVLIndexCursor::abort()
 	_pTM->getLockHandler()->unlockData(CegoObject::BTREE, _lockId);
 	_lockId = 0;
     }
-
 }
 
 void CegoAVLIndexCursor::reset()
@@ -657,7 +671,6 @@ void CegoAVLIndexCursor::reset()
 
 CegoComparison CegoAVLIndexCursor::compValue(char* idxVal)
 {
-
     CegoField* pF = _idxSchema.First();
 	     
     while ( pF ) 
@@ -707,8 +720,7 @@ CegoComparison CegoAVLIndexCursor::compValue(char* idxVal)
 	idxVal += flen;
 
 	pF = _idxSchema.Next();
-
     }
-
+    
     return EQUAL;
 }
