@@ -599,19 +599,19 @@ void CegoAVLIndexManager::deleteIndexTable(int tabSetId, const Chain& tableName,
     while ( ! entryFound && moreIndex )
     {
 	ie.setPtr(p, len);
-	bool leftBranch = false;
+	// bool leftBranch = false;
 	
 	TupleOrder v = compIndexValue(schema, idxPtr, ie.getIdxPtr());
 
 	if ( v == LT )
 	{
-	    leftBranch = true;
+	    // leftBranch = true;
 	    ptp = itp;
 	    itp = ie.getLeftBranch();
 	}
 	else if ( v == GT )
 	{
-	    leftBranch = false;
+	    // leftBranch = false;
 	    ptp = itp;	    
 	    itp = ie.getRightBranch();
 	}
