@@ -414,8 +414,7 @@ void CegoAdmAction::cleanQueryCacheAction()
 void CegoAdmAction::setQueryCacheParamAction()
 {
     Chain tableSet;
-    int numQueryEntry = 0;
-
+    
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -555,7 +554,6 @@ void CegoAdmAction::cleanTableCacheAction()
 void CegoAdmAction::setTableCacheParamAction()
 {
     Chain tableSet;
-    int numQueryEntry = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -1592,7 +1590,8 @@ void CegoAdmAction::setLogMngAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetLogMng(progName, _timeout);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1607,7 +1606,8 @@ void CegoAdmAction::setBackupMngAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetBackupMng(progName);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1688,10 +1688,10 @@ void CegoAdmAction::setTSInitFileAction()
     {
 	tableSet = *pS;
     }
-
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSInitFile(tableSet, initFileName);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1711,7 +1711,8 @@ void CegoAdmAction::setTSRootPathAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSRootPath(tableSet, tsRoot);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1737,7 +1738,8 @@ void CegoAdmAction::setTSLogNumAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSLogNum(tableSet, logNum);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1762,7 +1764,8 @@ void CegoAdmAction::setTSLogSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSLogSize(tableSet, logSize);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1787,7 +1790,8 @@ void CegoAdmAction::setTSSortAreaSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSSortAreaSize(tableSet, sortAreaSize);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1812,7 +1816,8 @@ void CegoAdmAction::setTSLogUserAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSLogUser(tableSet, logUser);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1837,7 +1842,8 @@ void CegoAdmAction::setTSSysSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSSysSize(tableSet, sysSize);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1862,7 +1868,8 @@ void CegoAdmAction::setTSTmpSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSTmpSize(tableSet, tmpSize);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1887,7 +1894,8 @@ void CegoAdmAction::setTSAppSizeAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetTSAppSize(tableSet, appSize);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1912,7 +1920,8 @@ void CegoAdmAction::setCheckpointAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqSetCheckpoint(tableSet, interval);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1930,7 +1939,8 @@ void CegoAdmAction::setNumQueryLastAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqNumQueryLast(numLast);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1948,7 +1958,8 @@ void CegoAdmAction::setNumQueryCostAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->reqNumQueryCost(numCost);
-
+    handleMedResult(res);
+    
     Chain msg;
     _pAH->getMsg(msg);
     if ( _rawMode == false )
@@ -1966,7 +1977,6 @@ void CegoAdmAction::switchSecondaryAction()
     
     CegoAdminHandler::ResultType res;
     res = _pAH->medSecSwitch(tableSet);
-
     handleMedResult(res);
 
     Chain msg;
@@ -1986,7 +1996,6 @@ void CegoAdmAction::switchMediatorAction()
     
     CegoAdminHandler::ResultType res;
     res = _pAH->secMedSwitch(tableSet);
-
     handleMedResult(res);
 
     Chain msg;
@@ -2009,7 +2018,6 @@ void CegoAdmAction::relocateSecondaryAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->medSecRelocate(tableSet, secondary);
-
     handleMedResult(res);
 
     Chain msg;
@@ -2032,7 +2040,6 @@ void CegoAdmAction::relocateMediatorAction()
     
     CegoAdminHandler::ResultType res;
     res = _pAH->secMedRelocate(tableSet, mediator);
-
     handleMedResult(res);
 
     Chain msg;
@@ -2052,7 +2059,6 @@ void CegoAdmAction::checkTableSetAction()
     
     CegoAdminHandler::ResultType res;
     res = _pAH->medCheckTableSet(tableSet);
-
     handleMedResult(res);
 
     CegoTableObject oe;
@@ -2074,6 +2080,7 @@ void CegoAdmAction::verifyTableSetAction()
 
     CegoAdminHandler::ResultType res;
     res = _pAH->medVerifyTableSet(tableSet);
+    
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
 	Chain msg;
@@ -2670,7 +2677,7 @@ void CegoAdmAction::importTableSetStructureAction()
 
 void CegoAdmAction::addDataFileAction()
 {
-    int numPages;
+    int numPages = 0;
     Chain tableSet;
     Chain dataFile(_stringBuf);
     Chain fileType;
@@ -3502,11 +3509,10 @@ void CegoAdmAction::dumpUIndex()
 
 void CegoAdmAction::handleMedResult(CegoAdminHandler::ResultType res)
 {
-    Chain msg;
-    _pAH->getMsg(msg);
-    
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
+	Chain msg;
+	_pAH->getMsg(msg);    
 	throw Exception(EXLOC, msg);
     }
     
@@ -3558,10 +3564,11 @@ void CegoAdmAction::handleMedResult(CegoAdminHandler::ResultType res)
     if ( _resultMode == VERBOSE )
 	output.tailOut();
     
-    _pAH->getMsg(msg);
     
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
+	Chain msg;
+	_pAH->getMsg(msg);
 	throw Exception(EXLOC, msg);
     }
 }
