@@ -75,10 +75,9 @@ void CegoAdmScreen::BufferPool::refresh()
 {    
     ListT<ListT<CegoFieldValue> > poolinfo;
 
-    CegoAdminHandler::ResultType res;
     CegoTableObject oe;
     
-    res = _pAH->reqPoolInfo();
+    _pAH->reqPoolInfo();
     
     _pAH->getPoolInfo(oe, poolinfo);
     
@@ -1913,7 +1912,7 @@ void CegoAdmScreen::TableSet::Action::FilePanel::refresh()
 	if (pFV )
 	{		
 	    Chain fileName=(char*)pFV->valAsChain();
-	    if ( fileName.length() > maxPathLen )
+	    if ( (int)fileName.length() > maxPathLen )
 		maxPathLen = fileName.length();		
 	}
 	pFVL = fileInfo.Next();	
@@ -2658,8 +2657,7 @@ Screen2::Panel* CegoAdmScreen::Role::Action::onSelect(int selected)
     }
     case 3:
     {
-	CegoAdminHandler::ResultType res;	
-	res = _pAH->reqShowUser();
+	_pAH->reqShowUser();
 	
 	CegoTableObject oe;
 	ListT<ListT<CegoFieldValue> > userList;
@@ -2668,7 +2666,6 @@ Screen2::Panel* CegoAdmScreen::Role::Action::onSelect(int selected)
 	
 	ListT<Chain> users;
 
-	int row=1;
 	ListT<CegoFieldValue> *pFVL = userList.First();
 	while ( pFVL )
 	{
@@ -2740,7 +2737,7 @@ Screen2::Panel* CegoAdmScreen::Role::Action::Perm::onKey(int c, int rowNum)
     else if ( c == KEY_DELETE )
     {
 	Chain permId = _permTable[rowNum-1][0];
-    
+
 	CegoAdminHandler::ResultType res;
 	res = _pAH->reqRemovePermission(_role, permId);
 		
@@ -2765,8 +2762,7 @@ ListT< ListT<Chain> > CegoAdmScreen::Role::Action::Perm::getData()
 
 void CegoAdmScreen::Role::Action::Perm::refresh()
 {
-    CegoAdminHandler::ResultType res;
-    res = _pAH->reqShowRole(_role);
+    _pAH->reqShowRole(_role);
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > permInfo;
@@ -3020,8 +3016,7 @@ ListT< ListT<Chain> > CegoAdmScreen::User::getData()
 
 void CegoAdmScreen::User::refresh()
 {   
-    CegoAdminHandler::ResultType res;	
-    res = _pAH->reqShowUser();
+    _pAH->reqShowUser();
     
     CegoTableObject oe;
     ListT<ListT<CegoFieldValue> > userList;
@@ -3030,7 +3025,6 @@ void CegoAdmScreen::User::refresh()
 			
     _userTable.Empty();
 
-    int row=1;
     ListT<CegoFieldValue> *pFVL = userList.First();
     while ( pFVL )
     {
@@ -3046,7 +3040,6 @@ void CegoAdmScreen::User::refresh()
 	
 	_userTable.Insert(userRow);
 	pFVL = userList.Next();
-	row++;
     }
 }
 
