@@ -359,7 +359,8 @@ public:
 				 const Chain& secondary,
 				 int sysFileSize, int tmpFileSize, int appFileSize,
 				 int logFileSize, int logFileNum,
-				 unsigned long long sortAreaSize);
+				 unsigned long long sortAreaSize,
+				 int branchId);
     
     ResultType medDropTableSet(const Chain& tableSet);
     ResultType medRemoveTableSet(const Chain& tableSet);
@@ -524,6 +525,7 @@ public:
     void getLogFileSize(int& logFileSize);
     void getLogFileNum(int& logFileNum);
     void getSortAreaSize(unsigned long long& sortAreaSize);
+    void getBranchId(int& branchId);
     void getArchId(Chain& archId);
     void getArchPath(Chain& archPath);
     void getHostRole(Chain& hostRole);
