@@ -1,7 +1,7 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                         
 // CegoAggregation.cc
-// -----------------
+// ------------------
 // Cego aggregation structure class implementation                                    
 //
 // Design and Implementation by Bjoern Lemke               
@@ -37,6 +37,7 @@ CegoAggregation::CegoAggregation(bool isDistinct)
 
 CegoAggregation::CegoAggregation(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
 {
+    _pExpr = 0;
     decode(buf, pGTM, pBlock, tabSetId);
 }
 
