@@ -185,7 +185,7 @@ Chain CegoAliasObject::getId(CegoProcBlock *pBlock) const
 
 Chain CegoAliasObject::toChain(int defTabSetId) const
 {
-    if ( defTabSetId == getTabSetId() && defTabSetId != 0 )
+    if ( ( defTabSetId == getTabSetId() && defTabSetId != 0 ) || defTabSetId == 0 )
 	return getName() + Chain(" ") + getTabAlias();
     else
 	return getName() + Chain("@") + getTableSet() + Chain(" ") + getTabAlias();
