@@ -229,7 +229,7 @@ void CegoBTreeManager::insertBTree(const CegoDataPointer& dp,
 	    lockId = _pObjMng->getLockHandler()->lockData(CegoObject::BTREE, pageId, CegoLockHandler::WRITE);
 	
 	bool isInserted = false;
-	bool isFirst = true;
+	// bool isFirst = true;
 	
 	while ( ! isInserted )
 	{
@@ -441,7 +441,7 @@ void CegoBTreeManager::insertBTree(const CegoDataPointer& dp,
 		}
 		isInserted = true;	    
 	    }
-	    isFirst = false;
+	    // isFirst = false;
 	}
     }
     catch ( Exception e )
@@ -584,7 +584,7 @@ void CegoBTreeManager::deleteBTree(const CegoDataPointer& sysEntry,
     
     bool isDeleted = false;
     StackT<CegoBufferPage> parentPageStack;
-    unsigned long long lockId;
+    unsigned long long lockId = 0;
     
     try
     {
@@ -708,8 +708,9 @@ void CegoBTreeManager::deleteBTree(const CegoDataPointer& sysEntry,
 	while ( parentPageStack.Pop(bp) )
 	{
 	    _pDBMng->bufferUnfix(bp, true, _pObjMng->getLockHandler());
-	}	
-	_pObjMng->getLockHandler()->unlockData(CegoObject::BTREE, lockId);	
+	}
+	if ( lockId > 0 )
+	    _pObjMng->getLockHandler()->unlockData(CegoObject::BTREE, lockId);	
 	throw Exception(EXLOC, Chain("Cannot delete from btree"), e);
     }
 
