@@ -1004,7 +1004,7 @@ bool CegoBTreeNode::nextChildPointer(PageIdType &pageId)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    if ( (long long)_pNextChild > (long long)_pI + sizeof(int) + numEntries() * getEntrySize() )
+    if ( (long long)_pNextChild > (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()) )
 	return false;
     
     memcpy(&pageId, _pNextChild, sizeof(PageIdType));
@@ -1021,7 +1021,7 @@ int CegoBTreeNode::getMedPage(int lb, int rb, PageIdType& pageId)
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
     
     int med = (lb + rb) / 2;
-    char* _pMed = (char*)((long long)_pI + sizeof(int) + med * getEntrySize());
+    char* _pMed = (char*)((long long)_pI + (long long)(sizeof(int) + med * getEntrySize()));
     
     memcpy(&pageId, _pMed, sizeof(PageIdType));
    
@@ -1034,7 +1034,7 @@ bool CegoBTreeNode::rightValue(int pos, CegoBTreeValue& val)
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
     char* pChild = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
-    if ( (long long)pChild > (long long)_pI + sizeof(int) + numEntries() * getEntrySize() )
+    if ( (long long)pChild > (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()))
 	return false;
         
     pChild+=sizeof(PageIdType);
@@ -1054,7 +1054,7 @@ void CegoBTreeNode::getLastChildPointer(PageIdType &pageId) const
     }
     else
     {
-	char *p = (char*)((long long)_pI + sizeof(int) + numEntries() * getEntrySize());    
+	char *p = (char*)((long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()));    
 	memcpy(&pageId, p, sizeof(PageIdType));
     }
 }
@@ -1064,7 +1064,7 @@ void CegoBTreeNode::setFirstChildPointer(PageIdType pageId)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    char *p = (char*)((long long)_pI + sizeof(int));    
+    char *p = (char*)((long long)_pI + (long long)sizeof(int));    
     memcpy(p, &pageId, sizeof(PageIdType));
 }
 
@@ -1073,7 +1073,7 @@ bool CegoBTreeNode::rightChild(CegoBTreeValue& val)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
    
-    if ( (long long)_pNextChild > (long long)_pI + sizeof(int) + numEntries() * getEntrySize() )
+    if ( (long long)_pNextChild > (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()))
 	return false;
     
     val.setPtr(_pNextChild - _keyLen, _keyLen);
@@ -1088,7 +1088,7 @@ void CegoBTreeNode::getValue(int pos, CegoBTreeValue& val, CegoDataPointer& dp)
     if ( pos >= numEntries() )
 	throw Exception(EXLOC, Chain("Node position out of range"));
 
-    char* pVal = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
+    char* pVal = (char*)((long long)_pI + (long long)(sizeof(int) + pos * getEntrySize()));
     
     val.setPtr(pVal, _keyLen);
     pVal +=_keyLen;
@@ -1100,7 +1100,7 @@ bool CegoBTreeNode::nextValue(CegoBTreeValue& val, CegoDataPointer& dp)
     if ( _nt == NODE )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    if ( (long long)_pNextChild >= (long long)_pI + sizeof(int) + numEntries() * getEntrySize() )
+    if ( (long long)_pNextChild >= (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()))
 	return false;
     
     val.setPtr(_pNextChild, _keyLen);
