@@ -103,7 +103,6 @@ int main(int argc, char **argv)
 	longOpt.addOpt("interval", Chain(DEFAULTINTERVAL));
 	longOpt.addOpt("append");
 	longOpt.addOpt("dotransaction");
-	longOpt.addOpt("debug");
 	longOpt.addOpt("server", DEFAULTSERVER);
 	longOpt.addOpt("port", Chain(DEFAULTPORT));
 	longOpt.addOpt("protocol", Chain(DEFAULTPROTOCOL));
@@ -125,11 +124,7 @@ int main(int argc, char **argv)
 	// for random generation in CegoFunction
 	unsigned seed = 5 * (time(NULL) % 100000); 	
 	srandom( seed  ); 
-	
-	bool isDebug=false;
-	if ( longOpt.isSet("debug") )
-	    isDebug=true;
-	
+		
 	if ( longOpt.isSet( Chain("help") ) )
 	{	
 	    cerr << USAGE << endl;
