@@ -93,7 +93,7 @@ void CegoBufferPool::initPool(unsigned long long numSegment, unsigned long long
 	    throw Exception(EXLOC, "Cannot initialize pool");
 	}
 	
-	for ( int i=0; i<_numSegment; i++)
+	for ( unsigned long long i=0; i<_numSegment; i++)
 	{
 	    _pBufPool[i] = malloc(_numPages * (BUFFERHEAD_SIZE + _pageSize) + BUFFERPOOLHEAD_SIZE);
 
@@ -123,7 +123,7 @@ void CegoBufferPool::initPool(unsigned long long numSegment, unsigned long long
 	    ibh.fixStat = 0;
 	    ibh.numUsage = 0;
 	    
-	    for (int i = 0; i<_numPages; i++)
+	    for (unsigned long long i = 0; i<_numPages; i++)
 	    {
 		memcpy(ptr, &ibh, BUFFERHEAD_SIZE );
 		ptr = (void*)((long long)ptr + BUFFERHEAD_SIZE + _pageSize);
@@ -144,7 +144,7 @@ void CegoBufferPool::removePool()
     {
 	log(_modId, Logger::NOTICE, Chain("Removing pool ..."));
 	
-	for ( int i=0; i<_numSegment; i++)
+	for ( unsigned long long i=0; i<_numSegment; i++)
 	{
 	    free ( _pBufPool[i] );	   
 	}
@@ -299,7 +299,7 @@ void CegoBufferPool::bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType page
 	    {		
 		if ( ( ( pBH->isOccupied != PERSISTENT_OCCUPIED && pBH->isDirty == 0 )
 		       || pBH->isOccupied == WRITE_ON_DIRTY )
-		     && pBH->numFixes == 0 && ( minFixStat > pBH->fixStat || minFixStat == -1))
+		     && pBH->numFixes == 0 && ( minFixStat > (int)pBH->fixStat || minFixStat == -1))
 		{
 		    minFixStatBufPtr = bufPtr;
 		    // cout << "Found page with minFixStat = " << bh.fixStat << endl;
@@ -559,7 +559,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(const Chain& tableSet, bool s
 
     Datetime tsStart;
     
-    unsigned long long archExceed = tsStart.asLong() + archTimeout;
+    long long archExceed = tsStart.asLong() + archTimeout;
     if ( archComplete )
     {
 	while ( archiveComplete(tableSet) == false )
@@ -717,11 +717,11 @@ unsigned long long CegoBufferPool::writeCheckPoint(int tabSetId, bool switchLog,
 	    // sync control information to xml database file
 	    doc2Xml();
 	    
-	    for ( int i=0; i<_numSegment; i++)
+	    for ( unsigned long long i=0; i<_numSegment; i++)
 	    {
 		void *bufPtr = (void*)( (long long)_pBufPool[i] + BUFFERPOOLHEAD_SIZE );
 		
-		int pageCount = 0;
+		unsigned long long pageCount = 0;
 		
 		while ( pageCount < _numPages )
 		{
@@ -820,11 +820,11 @@ void CegoBufferPool::dumpCheckpoint(int tabSetId)
     
     cpd.startWrite();
     	    
-    for ( int i=0; i<_numSegment; i++)
+    for ( unsigned long long i=0; i<_numSegment; i++)
     {
 	void *bufPtr = (void*)( (long long)_pBufPool[i] + BUFFERPOOLHEAD_SIZE );
 	
-	int pageCount = 0;
+	unsigned long long pageCount = 0;
 	
 	while ( pageCount < _numPages )
 	{
@@ -955,11 +955,11 @@ void CegoBufferPool::writeAndRemoveTabSet(int tabSetId, CegoLockHandler *pLockHa
 	throw Exception(EXLOC, "No valid bufferpool");
     }
 
-    for ( int i=0; i<_numSegment; i++)
+    for ( unsigned long long i=0; i<_numSegment; i++)
     {
 	void *bufPtr = (void*)( (long long)_pBufPool[i] + BUFFERPOOLHEAD_SIZE );
 	
-	int pageCount = 0;
+	unsigned long long pageCount = 0;
 	
 	while ( pageCount < _numPages )
 	{
@@ -1031,13 +1031,13 @@ void CegoBufferPool::poolInfo(int& pageSize,
 
     unsigned long long numUsage = 0;
     
-    for ( int i=0; i<_numSegment; i++)
+    for ( unsigned long long i=0; i<_numSegment; i++)
     {
 	void *bufPtr = (void*)( (long long)_pBufPool[i] + BUFFERPOOLHEAD_SIZE );
 	
 	unsigned long long pageCount = 0;
 
-	unsigned long long numSegPageUsed = 0;
+	// unsigned long long numSegPageUsed = 0;
 	
 	while ( pageCount < _numPages )
 	{    
@@ -1057,18 +1057,18 @@ void CegoBufferPool::poolInfo(int& pageSize,
 	    }
 	    else if (bh.isOccupied == WRITE_ON_SYNC)
 	    {
-		numSegPageUsed++;
+		// numSegPageUsed++;
 		numUsed++;
 	    }
 	    else if (bh.isOccupied == WRITE_ON_DIRTY)
 	    {
-		numSegPageUsed++;
+		// numSegPageUsed++;
 		numUsed++;
 		numNoSync++;
 	    }
 	    else if (bh.isOccupied == PERSISTENT_OCCUPIED)
 	    {
-		numSegPageUsed++;
+		// numSegPageUsed++;
 		numUsed++;
 		numPersistent++;
 	    }   
@@ -1088,7 +1088,7 @@ void CegoBufferPool::poolInfo(int& pageSize,
     double usageMedian = (double)numUsage / (double)( _numSegment * _numPages );
     double usageDist = 0.0;
     
-    for ( int i=0; i<_numSegment; i++)
+    for ( unsigned long long i=0; i<_numSegment; i++)
     {
 	void *bufPtr = (void*)( (long long)_pBufPool[i] + BUFFERPOOLHEAD_SIZE );
 	
@@ -1137,7 +1137,7 @@ void CegoBufferPool::getPoolEntryList(ListT<CegoBufferPoolEntry>& entryList)
 
     entryList.Empty();
     
-    for ( int seg=0; seg<_numSegment; seg++)
+    for ( unsigned long long seg=0; seg<_numSegment; seg++)
     {
 	void *bufPtr = (void*)( (long long)_pBufPool[seg] + BUFFERPOOLHEAD_SIZE );
 	    
@@ -1239,7 +1239,7 @@ void CegoBufferPool::printPool()
     unsigned long long numFixes=0;
     unsigned long long numDirty=0;
 
-    for ( int i=0; i<_numSegment; i++)
+    for ( unsigned long long i=0; i<_numSegment; i++)
     {
 	void *bufPtr = (void*)( (long long)_pBufPool[i] + BUFFERPOOLHEAD_SIZE );
 	
@@ -1378,7 +1378,7 @@ void CegoBufferPool::optimizePool(int tabSetId)
     
     unsigned long long numRelocated = 0;
 	
-    for ( int seg=0; seg<_numSegment; seg++)
+    for ( unsigned long seg=0; seg<_numSegment; seg++)
     {
 	void *basePtr = (void*)( (long long)_pBufPool[seg] + BUFFERPOOLHEAD_SIZE );
 	    
@@ -1391,7 +1391,7 @@ void CegoBufferPool::optimizePool(int tabSetId)
 
 	    if ( ( bh.isOccupied == WRITE_ON_SYNC || bh.isOccupied == WRITE_ON_DIRTY ) && bh.tabSetId == tabSetId && bh.numFixes == 0 )
 	    {	    
-		int hashId = calcHash(bh.pageId);
+		unsigned long long hashId = calcHash(bh.pageId);
 
 		if ( pageIndex != hashId )
 		{		    
