@@ -318,6 +318,20 @@ CegoCaseCond& CegoCaseCond::operator = ( const CegoCaseCond& cc)
     return (*this);
 }
 
+void CegoCaseCond::getSelectQueryList(ListT<CegoSelect*>& queryList)
+{
+    CegoPredicate **pPredDesc = _predList.First();
+    CegoExpr **pExpr = _exprList.First();
+    while ( pPredDesc && pExpr)
+    {
+	(*pPredDesc)->getSelectQueryList(queryList);
+	(*pExpr)->getSelectQueryList(queryList);
+	pPredDesc = _predList.Next();
+	pExpr = _exprList.Next();
+    }    
+    _elseExpr->getSelectQueryList(queryList);
+}
+
 Chain CegoCaseCond::getId(CegoProcBlock *pBlock) const
 {
     Chain s;
@@ -442,3 +456,59 @@ ostream& operator << (ostream& s, const CegoCaseCond& cc)
     s << cc.toChain(0);
     return s;
 }
+
+
+
+CegoCaseCond* CegoCaseCond::map(const Chain& viewAlias, const ListT<CegoExpr*>& exprList) const
+{
+
+    bool doMap=true;
+
+    
+    CegoCaseCond *pCaseCond = new CegoCaseCond();
+    
+    CegoPredicate **pPred = _predList.First();
+    CegoExpr **pExpr = _exprList.First();
+
+    while ( pPred && pExpr && doMap)
+    {	
+	CegoExpr* pMapExpr = (*pExpr)->map(viewAlias, exprList);
+	if ( pMapExpr == 0 )
+	    doMap = false;
+
+	if ( doMap )
+	{
+	    CegoPredicate* pMapPred = (*pPred)->map(viewAlias, exprList);
+	    if ( pMapPred == 0 )
+		doMap = false;
+
+	    if ( doMap )
+	    {
+		pCaseCond->addPred(pMapPred, pMapExpr);	    
+	    }
+	}
+
+	pPred = _predList.Next();
+	pExpr = _exprList.Next();
+
+    }
+
+    if ( doMap )
+    {
+    	CegoExpr* pMapElse = _elseExpr->map(viewAlias, exprList);
+	if ( pMapElse == 0)
+	    doMap = false;
+	if ( doMap )
+	    pCaseCond->setElseExpr(pMapElse);	    
+    }
+    
+    if ( doMap )
+    {	
+	return pCaseCond;
+    }
+    else
+    {
+	delete pCaseCond;	
+	return 0;
+    }
+}
