@@ -44,8 +44,8 @@ public:
 	CheckpointEntry(const Chain& ts, unsigned long long nextCP) { _ts = ts; _nextCP = nextCP; };
 	~CheckpointEntry() {};
 	       
-	unsigned long long getNextCP() { return _nextCP; };
-	void setNextCP(unsigned long long nextCP) { _nextCP = nextCP; };
+	long long getNextCP() { return _nextCP; };
+	void setNextCP(long long nextCP) { _nextCP = nextCP; };
 
 	CheckpointEntry& operator = ( const CheckpointEntry& cp) { 
 	    _ts = cp._ts;
@@ -59,7 +59,7 @@ public:
 	
     private:
 	Chain _ts;
-	unsigned long long _nextCP;
+	long long _nextCP;
     };
 
     ListT<CheckpointEntry> _tsList;
