@@ -1070,7 +1070,7 @@ bool dispatchCmd(CegoNet *pCegoNet, AbortHandler *pAH, Chain cmd, bool rawMode,
 		while ( hasData )
 		{
 		    // collect data
-		    int i=0;
+		    unsigned long long i=0;
 		    ListT<CegoFieldValue > pfvl;		    
 		    ListT<CegoFieldValue> fvl;
 
@@ -1210,8 +1210,7 @@ void dumpProlog(File *pDF)
 
 void dumpCounter(CegoNet *pCegoNet, File *pDF)
 {
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list counter;"));
+    pCegoNet->doQuery(Chain("list counter;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1239,8 +1238,8 @@ void dumpCounter(CegoNet *pCegoNet, File *pDF)
 
 void dumpTable(CegoNet *pCegoNet, File *pDF, bool isStructure)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list table;"));
+
+    pCegoNet->doQuery(Chain("list table;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1258,7 +1257,7 @@ void dumpTable(CegoNet *pCegoNet, File *pDF, bool isStructure)
     Chain *pTable = tableList.First();
     while ( pTable ) 
     {
-	res = pCegoNet->doQuery(Chain("desc table ") + *pTable + Chain(";"));
+	pCegoNet->doQuery(Chain("desc table ") + *pTable + Chain(";"));
 
 	Chain cmd;
 
@@ -1328,7 +1327,7 @@ void dumpTable(CegoNet *pCegoNet, File *pDF, bool isStructure)
 	if ( isStructure == false )
 	{
 	    // dump table content
-	    res = pCegoNet->doQuery(Chain("select ") + selectAttr + Chain(" from ") + *pTable + Chain(";"));
+	    pCegoNet->doQuery(Chain("select ") + selectAttr + Chain(" from ") + *pTable + Chain(";"));
 	    
 	    schema.Empty();
 	    fvl.Empty();
@@ -1361,8 +1360,7 @@ void dumpTable(CegoNet *pCegoNet, File *pDF, bool isStructure)
 
 void dumpAVLtree(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list avltree;"));
+    pCegoNet->doQuery(Chain("list avltree;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1380,7 +1378,7 @@ void dumpAVLtree(CegoNet *pCegoNet, File *pDF)
     Chain *pAVL = avlList.First();
     while ( pAVL ) 
     {
-	res = pCegoNet->doQuery(Chain("desc avltree ") + *pAVL + Chain(";"));
+	pCegoNet->doQuery(Chain("desc avltree ") + *pAVL + Chain(";"));
 
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
@@ -1438,8 +1436,7 @@ void dumpAVLtree(CegoNet *pCegoNet, File *pDF)
 
 void dumpBtree(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list btree;"));
+    pCegoNet->doQuery(Chain("list btree;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1457,7 +1454,7 @@ void dumpBtree(CegoNet *pCegoNet, File *pDF)
     Chain *pIndex = indexList.First();
     while ( pIndex ) 
     {
-	res = pCegoNet->doQuery(Chain("desc btree ") + *pIndex + Chain(";"));
+	pCegoNet->doQuery(Chain("desc btree ") + *pIndex + Chain(";"));
 
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
@@ -1515,8 +1512,7 @@ void dumpBtree(CegoNet *pCegoNet, File *pDF)
 
 void dumpKey(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list key;"));
+    pCegoNet->doQuery(Chain("list key;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1534,7 +1530,7 @@ void dumpKey(CegoNet *pCegoNet, File *pDF)
     Chain *pKey = keyList.First();
     while ( pKey ) 
     {
-	res = pCegoNet->doQuery(Chain("desc key ") + *pKey + Chain(";"));
+	pCegoNet->doQuery(Chain("desc key ") + *pKey + Chain(";"));
 	
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
@@ -1602,8 +1598,7 @@ void dumpKey(CegoNet *pCegoNet, File *pDF)
 
 void dumpCheck(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list check;"));
+    pCegoNet->doQuery(Chain("list check;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1621,7 +1616,7 @@ void dumpCheck(CegoNet *pCegoNet, File *pDF)
     Chain *pCheck = checkList.First();
     while ( pCheck ) 
     {
-	res = pCegoNet->doQuery(Chain("desc check ") + *pCheck + Chain(";"));
+	pCegoNet->doQuery(Chain("desc check ") + *pCheck + Chain(";"));
 
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
@@ -1650,8 +1645,7 @@ void dumpCheck(CegoNet *pCegoNet, File *pDF)
 
 void dumpView(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list view;"));
+    pCegoNet->doQuery(Chain("list view;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1669,7 +1663,7 @@ void dumpView(CegoNet *pCegoNet, File *pDF)
     Chain *pView = viewList.First();
     while ( pView ) 
     {
-	res = pCegoNet->doQuery(Chain("show view ") + *pView + Chain(";"));
+	pCegoNet->doQuery(Chain("show view ") + *pView + Chain(";"));
 
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
@@ -1698,8 +1692,7 @@ void dumpView(CegoNet *pCegoNet, File *pDF)
 
 void dumpProcedure(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list procedure;"));
+    pCegoNet->doQuery(Chain("list procedure;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1717,7 +1710,7 @@ void dumpProcedure(CegoNet *pCegoNet, File *pDF)
     Chain *pProc = procList.First();
     while ( pProc ) 
     {
-	res = pCegoNet->doQuery(Chain("show procedure ") + *pProc + Chain(";"));
+	pCegoNet->doQuery(Chain("show procedure ") + *pProc + Chain(";"));
 
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
@@ -1746,8 +1739,7 @@ void dumpProcedure(CegoNet *pCegoNet, File *pDF)
 
 void dumpAlias(CegoNet *pCegoNet, File *pDF)
 {	
-    unsigned long long res;
-    res = pCegoNet->doQuery(Chain("list alias;"));
+    pCegoNet->doQuery(Chain("list alias;"));
         
     ListT<CegoField> schema;
     pCegoNet->getSchema(schema);
@@ -1765,7 +1757,7 @@ void dumpAlias(CegoNet *pCegoNet, File *pDF)
     Chain *pAlias = aliasList.First();
     while ( pAlias ) 
     {
-	res = pCegoNet->doQuery(Chain("desc alias ") + *pAlias + Chain(";"));
+	pCegoNet->doQuery(Chain("desc alias ") + *pAlias + Chain(";"));
 	
 	ListT<CegoField> schema;
 	pCegoNet->getSchema(schema);
