@@ -97,7 +97,7 @@ void CegoClob::writeClob(const Chain& fileName)
 
     int writtenByte = wb;
 
-    while ( writtenByte < _size )  
+    while ( writtenByte < (int)_size )  
     {
 	bufPtr += wb;
 	wb = _size - wb > CLOB_BLOCKSIZE ? CLOB_BLOCKSIZE : _size - wb;
