@@ -503,21 +503,25 @@ CegoCondition* CegoCondition::map(const Chain& viewAlias, const ListT<CegoExpr*>
 
 bool CegoCondition::isCursorPred() const
 {
-
+    bool isPred = false;
+    
     switch( _condType )
     {
     case CegoCondition::AND:
     {
-	return _pLeft->isCursorPred() &&  _pRight->isCursorPred();
+	isPred = _pLeft->isCursorPred() &&  _pRight->isCursorPred();
+	break;
     }
     case CegoCondition::OR:
     {
-	return false;
+	isPred = false;
+	break;
     }
     case CegoCondition::PRED:
     {
-	return _pLeft->isCursorPred();
+        isPred = _pLeft->isCursorPred();
 	break;
     }
     }
+    return isPred;
 }
