@@ -106,7 +106,7 @@ int CegoContentObject::getSchemaSize() const
     while (pF)
     {
 	// key information
-	schemaSize += sizeof(char);
+	// schemaSize += sizeof(char);
 
 	// field id information
 	schemaSize += sizeof(int);
@@ -186,10 +186,12 @@ void CegoContentObject::encodeBaseContent(char *buf, int size) const
     CegoField* pF = _schema.First();
     while (pF)
     {
+	/*
 	char c;
 	c = true; // pF->isPrimary();
 	memcpy (bufPtr, &c , 1);
 	bufPtr++;
+	*/
 	
 	int id = pF->getId();
 	memcpy (bufPtr, &id , sizeof(int));
@@ -265,16 +267,18 @@ void CegoContentObject::decodeBaseContent(char *buf, int& size)
     _schema.Empty();
     while ((bufPtr - schemaBase) < schemaSize)
     {
-	bool isPrimary;
+	// bool isPrimary;
 	bool isNullable;
 	char c;
 	CegoDataType type;
 	int id;
 	Chain attrName, tableName, tableAlias;
-	
+
+	/*
 	memcpy (&c, bufPtr , 1);
-	isPrimary=c;
+	// isPrimary=c;
 	bufPtr++;
+	*/
 	
 	memcpy (&id, bufPtr, sizeof(int));
 	bufPtr += sizeof(int);
@@ -323,6 +327,7 @@ CegoContentObject& CegoContentObject::operator = ( const CegoContentObject& co)
     _tabName = co._tabName;
     _tabAlias = co._tabAlias;
     _schema = co._schema;
+
     return (*this);
 }
 
