@@ -8,14 +8,14 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
 // Class: CegoContentObject
 //
-// Description: This is a super class for all content classes like CegoTableObject, CegoIndexObject, and others which are used
-//              to describe data content objects.
+// Description: This is a super class for all content classes like CegoTableObject, CegoIndexObject
+//              and others which are used to describe data content objects.
 //
 // Status: CLEAN
 //
@@ -28,6 +28,7 @@
 
 // CEGO INCLUDES
 #include "CegoField.h"
+#include "CegoProcBlock.h"
 #include "CegoDecodableObject.h"
 
 class CegoContentObject : public CegoDecodableObject {
@@ -48,22 +49,22 @@ public:
     const Chain& getTabAlias() const;
     
     virtual void setSchema(const ListT<CegoField>& schema) = 0;   
-    ListT<CegoField>& getSchema();
+    const ListT<CegoField>& getSchema();
     
     ListT<CegoContentObject*>& getSubCOList();
 
     CegoContentObject& operator = ( const CegoContentObject& co);
     bool operator == ( const CegoContentObject& co);
 
-    virtual Chain getId() const = 0;
-    virtual Chain toChain() const = 0;
+    virtual Chain getId(CegoProcBlock *pBlock) const = 0;
+    virtual Chain toChain(int defTabSetId) const = 0;
     virtual CegoContentObject* clone(bool isAttrRef) = 0;
     
 protected:
 
     int getBaseContentSize() const;
 
-    void encodeBaseContent(char *buf, int size);
+    void encodeBaseContent(char *buf, int size) const;
     void decodeBaseContent(char *buf, int& size);
 
     void setEmpty();
