@@ -294,12 +294,12 @@ void CegoDatabaseManager::DbSessionRecord::setUsed(bool isUsed)
     _isUsed = isUsed;
 }
 
-unsigned long long CegoDatabaseManager::DbSessionRecord::getTSLastUsed()
+long long CegoDatabaseManager::DbSessionRecord::getTSLastUsed()
 {
     return _lastUsed;
 }
 
-void CegoDatabaseManager::DbSessionRecord::setTSLastUsed(unsigned long long ts)
+void CegoDatabaseManager::DbSessionRecord::setTSLastUsed(long long ts)
 {
     _lastUsed = ts;
 }
@@ -1107,7 +1107,7 @@ Element* CegoDatabaseManager::getSessionInfo(int lifetime)
 	    pN->setAttribute(XML_ISUSED_ATTR, XML_FALSE_VALUE);
 
 	Datetime dt;
-	pN->setAttribute(XML_TTL_ATTR, Chain(pSR->getTSLastUsed() + (unsigned long long)lifetime - dt.asLong()));	
+	pN->setAttribute(XML_TTL_ATTR, Chain(pSR->getTSLastUsed() + (long long)lifetime - dt.asLong()));	
 
 	pSessionInfo->addContent(pN);
 
