@@ -244,8 +244,8 @@ private:
 
 	bool isUsed() const;
 	void setUsed(bool isUsed);
-	unsigned long long getTSLastUsed();
-	void setTSLastUsed(unsigned long long ts);
+	long long getTSLastUsed();
+	void setTSLastUsed(long long ts);
 
 	CegoDistDbHandler* getDbHandler() const;
 
@@ -263,7 +263,7 @@ private:
 	Chain _hostName;
 	Chain _tableSet;
 	Chain _userName;
-	unsigned long long _lastUsed;
+	long long _lastUsed;
 	bool _isUsed;
 	CegoDistDbHandler* _pHandler;
     };
