@@ -1417,7 +1417,7 @@ CegoDbHandler::ResultType CegoDbHandler::getBlob(CegoBlob& blob)
     blob.allocate(blobSize);
     blob.reset();
     
-    int recvSize = 0;
+    unsigned long long recvSize = 0;
     while ( recvSize < blobSize )
     {
        	_pN->sendAck();
@@ -1707,7 +1707,7 @@ CegoDbHandler::ResultType CegoDbHandler::getClob(CegoClob& clob)
     clob.allocate(clobSize);
     clob.reset();
     
-    int recvSize = 0;
+    unsigned long long recvSize = 0;
     while ( recvSize < clobSize )
     {
        	_pN->sendAck();
