@@ -1138,7 +1138,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 		    else // just take the needed
 		    {
 			// take the full page chunk ?
-			if (  bp.getChunkLen() < blobSize - sentByte  )
+			if (  (unsigned long long)bp.getChunkLen() < blobSize - sentByte  )
 			{
 			    chunkSize = bp.getChunkLen();
 			}
@@ -1378,7 +1378,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 		    else // just take the needed
 		    {
 			// take the full page chunk ?
-			if (  bp.getChunkLen() < clobSize - sentByte  )
+			if (  (unsigned long long)bp.getChunkLen() < clobSize - sentByte  )
 			{
 			    chunkSize = bp.getChunkLen();
 			}
@@ -1541,7 +1541,7 @@ void CegoDbThread::addHistory(unsigned long long ts, const Chain& queryString, u
 	    costEntry.setCostOrder();
 	    _costTree.Insert(costEntry);
 	    QueryEntry *pFirst = _costTree.First();
-	    if ( pFirst && _costTree.Size() >= _numCost )
+	    if ( pFirst && (int)_costTree.Size() >= _numCost )
 		_costTree.Remove(*pFirst);
 	}
 	
