@@ -1135,7 +1135,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 		     || _tableName == Chain(SYSTAB_INDEX_ID)
 		     || _tableName == Chain(SYSTAB_BTREE_ID) )
 		{	    
-		    int pageCount;
+		    int pageCount = 0;
 		    
 		    if ( _tableName == Chain(SYSTAB_TABLE_ID)  )
 			pageCount = _pGTM->getPageCount(_tabSetId, *pName, CegoObject::TABLE);
@@ -1193,7 +1193,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 	return _moreTuple;
     }
     else if ( _pCO->getType() == CegoObject::JOIN )
-    {		
+    {	
 	if ( _isFirst )
 	{
 	    _moreLeft = true;
@@ -1212,6 +1212,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 		{
 		    // cout << "OuterCond=" << _outerCond.toChain() << endl;
 		    _pTCLeft->distSetup(_outerCond, _pFLA, _pPropPred);
+		    		    
 		    _moreLeft = _pTCLeft->nextTuple(pFLA, offset, size-1);
 		    if ( _moreLeft )
 		    {
@@ -1228,7 +1229,6 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 			{
 			    _pTCRight->distSetup(_pFLA, _pPropPred);
 			}
-			
 			_moreRight = _pTCRight->nextTuple(pFLA, offset+size-1, 1);
 		    }
 		    _isFirst = false;
@@ -1276,6 +1276,7 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 		    }
 		}
 
+		
 		if ( _moreLeft && _moreRight )
 		{
 		    if ( _evalPredicate )
@@ -1304,9 +1305,8 @@ bool CegoDistCursor::getTuple(ListT<CegoField>** pFLA, int offset, int size)
 						       0,							       
 						       _pBlock);    			
 		    }
-		    
-		    
 		}
+				
 	    }
 	    return _moreLeft && _moreRight;
 	}
