@@ -1,12 +1,12 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                         
 // CegoDistDbHandler.cc
-// ----------------------
+// --------------------
 // Cego global db handler class implementation
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -37,6 +37,7 @@ CegoDistDbHandler::~CegoDistDbHandler()
 {
 }
 
+/*
 void CegoDistDbHandler::getDeleteArg(Chain& tableSet, Chain& tableName, CegoPredDesc*& pPred,
 				     CegoDistManager *pGTM)
 {
@@ -79,16 +80,7 @@ void CegoDistDbHandler::getUpdateArg(Chain& tableSet,
 	    
 	    tableSet = pRoot->getAttributeValue(XML_TABLESET_ATTR);	
 	    tableName = _xml.getDocument()->getRootElement()->getAttributeValue(XML_TABLENAME_ATTR);
-	    
-	    /*
-	      Chain lastPageValue = _xml.getDocument()->getRootElement()->getAttributeValue(XML_LASTPAGE_ATTR);
-	      
-	      if ( lastPageValue == Chain(XML_TRUE_VALUE) )
-	      lastPage = true;
-	      else
-	      lastPage = false;
-	    */
-	    
+	    	    
 	    ListT<Element*> pel = _xml.getDocument()->getRootElement()->getChildren(XML_PRED_ELEMENT);
 	    
 	    Element **pPE = pel.First();
@@ -103,12 +95,12 @@ void CegoDistDbHandler::getUpdateArg(Chain& tableSet,
 	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
     }	
 }
+*/
 
 void CegoDistDbHandler::getCreateTableArg(Chain& tableSet, Chain& tableName, ListT<CegoField>& fl, ListT<CegoField>& idxList)
 {    
     if ( _protType == CegoDbHandler::XML )
-    {
-	
+    {	
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
@@ -142,7 +134,6 @@ void CegoDistDbHandler::getCreateViewArg(Chain& tableSet, Chain& viewName, ListT
 {
     if ( _protType == CegoDbHandler::XML )
     {
-    
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
@@ -176,7 +167,6 @@ void CegoDistDbHandler::getCreateProcedureArg(Chain& tableSet, Chain& procName,
 {
     if ( _protType == CegoDbHandler::XML )
     {
-	
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{
@@ -191,6 +181,8 @@ void CegoDistDbHandler::getCreateProcedureArg(Chain& tableSet, Chain& procName,
     }
 }
 
+/* deprecated, since XML encoding for PredDesc is no more supported
+
 void CegoDistDbHandler::getCreateCheckArg(Chain& tableSet, Chain& checkName, Chain& tableName, CegoPredDesc*& pPred,
 				     CegoDistManager *pGTM)
 {
@@ -247,6 +239,8 @@ void CegoDistDbHandler::getAlterTableArg(Chain& tableSet, Chain& tableName, List
     }
 }
 
+*/
+
 void CegoDistDbHandler::getDropTableArg(Chain& tableSet, Chain& tableName, CegoObject::ObjectType& type)
 {
     if ( _protType == CegoDbHandler::XML )
@@ -335,8 +329,7 @@ void CegoDistDbHandler::getGetTableArg(int& tabSetId, Chain& tableName, CegoObje
 	    tableName = pRoot->getAttributeValue(XML_TABLENAME_ATTR);
 	    
 	    CegoTypeConverter tc;
-	    type = tc.getObjectTypeId(pRoot->getAttributeValue(XML_TABLETYPE_ATTR));
-	    
+	    type = tc.getObjectTypeId(pRoot->getAttributeValue(XML_TABLETYPE_ATTR));	    
 	}
     }
     else
@@ -359,7 +352,6 @@ void CegoDistDbHandler::getRenameArg(Chain& tableSet, Chain& objName, CegoObject
 	    type = tc.getObjectTypeId(pRoot->getAttributeValue(XML_TABLETYPE_ATTR));
 	    
 	    newObjName = pRoot->getAttributeValue(XML_NEWOBJNAME_ATTR);
-	
 	}
     }
     else
@@ -523,6 +515,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqInsertOp(const Chain& tableS
     }
 }
 
+/*
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqUpdateOp(const Chain& tableSet, 
 							     const Chain& tableName,
 							     const ListT<CegoField>& updSchema, 
@@ -577,6 +570,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqDeleteOp(const Chain& tableS
 	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
     }
 }
+*/
 
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateTableOp(const Chain& tableSet, const Chain& tableName, CegoObject::ObjectType type,
 								  const ListT<CegoField>& fl, const ListT<CegoField>& idxList)
@@ -609,6 +603,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateTableOp(const Chain& t
     }
 }
 
+/*
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqAlterTableOp(const Chain& tableSet, const Chain& tableName, const ListT<CegoAlterDesc>& alterList)
 {
     if ( _protType == CegoDbHandler::XML )
@@ -632,6 +627,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqAlterTableOp(const Chain& ta
 	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
     }
 }
+*/
 
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateIndexOp(const Chain& tableSet, 
 								  const Chain& indexName, 
@@ -843,6 +839,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqReorgObjectOp(const Chain& t
     }
 }
 
+/*
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateCheckOp(const Chain& tableSet, const Chain& checkName, const Chain& tableName, CegoPredDesc* pPred)
 {    
     if ( _protType == CegoDbHandler::XML )
@@ -862,6 +859,7 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateCheckOp(const Chain& t
 	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
     }
 }
+*/
 
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqObjectInfoOp(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
@@ -950,6 +948,23 @@ CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateProcOp(const Chain& ta
     }
 }
 
+CegoDistDbHandler::ResultType CegoDistDbHandler::reqCreateTriggerOp(const Chain& tableSet, const Chain& triggerName, const Chain& tableName, const Chain& triggerText)
+{
+    if ( _protType == CegoDbHandler::XML )
+    {
+	Element* pRoot = new Element(XML_FRAME_ELEMENT);
+	pRoot->setAttribute(XML_TABLESET_ATTR, tableSet);
+	pRoot->setAttribute(XML_TRIGGERNAME_ATTR, triggerName);
+	pRoot->setAttribute(XML_TABLENAME_ATTR, tableName);
+	pRoot->setAttribute(XML_TRIGGERTEXT_ATTR, triggerText);
+	return sendXMLReq(XML_CREATETRIGGER_REQUEST, pRoot);
+    }
+    else
+    {
+	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
+    }
+}
+
 CegoDistDbHandler::ResultType CegoDistDbHandler::reqStartTransactionOp(const Chain& tableSet)
 {
     if ( _protType == CegoDbHandler::XML )
@@ -1111,63 +1126,14 @@ void CegoDistDbHandler::sendObjList(const ListT<Chain>& objList)
 void CegoDistDbHandler::sendObjByTableList(const ListT<CegoTableObject>& idxList,
 					   const ListT<CegoKeyObject>& keyList,
 					   const ListT<CegoCheckObject>& checkList)
-{    
-    if ( _protType == CegoDbHandler::XML )
-    {	
-	_xml.getDocument()->clear();
-	
-	Element* pRoot = new Element(XML_FRAME_ELEMENT);
-	
-	CegoTableObject *pIdx = idxList.First();
-	while ( pIdx ) 
-	{
-	    pRoot->addContent(pIdx->getElement());
-	    pIdx = idxList.Next();
-	}
-	
-	CegoKeyObject *pKey = keyList.First();
-	while ( pKey ) 
-	{
-	    pRoot->addContent(pKey->getElement());
-	    pKey = keyList.Next();
-	}
-	
-	CegoCheckObject *pCheck = checkList.First();
-	while ( pCheck ) 
-	{
-	    pRoot->addContent(pCheck->getElement());
-	    pCheck = checkList.Next();
-	}
-	
-	_xml.getDocument()->setRootElement(pRoot);    
-	_xml.getDocument()->setDocType(XML_INFO_DOC);
-	
-	Chain response;
-	_xml.getXMLChain(response);
-	
-	
-#ifdef DEBUG
-	_pModule->log(_modId, Logger::DEBUG, Chain("--- XML ---"));
-	_pModule->log(_modId, Logger::DEBUG, response);
-	_pModule->log(_modId, Logger::DEBUG, Chain("--- --- ---"));
-#endif
-	
-	_pN->setMsg((char*)response, response.length());
-	_pN->writeMsg();
-	
-	_xml.getDocument()->clear();
-    }
-    else
-    {
-	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
-    }
+{
+    throw Exception(EXLOC, Chain("No more supported"));
 }
 
 void CegoDistDbHandler::sendTID(int tid)
 {
     if ( _protType == CegoDbHandler::XML )
-    {
-	
+    {	
 	_xml.getDocument()->clear();
 	
 	Element* pRoot = new Element(XML_FRAME_ELEMENT);
@@ -1233,8 +1199,7 @@ void CegoDistDbHandler::sendPageCount(int pageCount)
 void CegoDistDbHandler::getObjectList(ListT<Chain>& objList)
 {   
     if ( _protType == CegoDbHandler::XML )
-    {
-	
+    {	
 	Element *pRoot = _xml.getDocument()->getRootElement();
 	if ( pRoot )
 	{	    
@@ -1258,6 +1223,7 @@ void CegoDistDbHandler::getObjectByTableList(ListT<CegoTableObject>& idxList,
 					     ListT<CegoKeyObject>& keyList,
 					     ListT<CegoCheckObject>& checkList)
 {
+    /*
     if ( _protType == CegoDbHandler::XML )
     {	
 	Element *pRoot = _xml.getDocument()->getRootElement();
@@ -1297,7 +1263,18 @@ void CegoDistDbHandler::getObjectByTableList(ListT<CegoTableObject>& idxList,
 		    checkList.Insert(co);
 		    break;
 		}
-		default:
+		case CegoObject::SYSTEM:
+		case CegoObject::TABLE:
+		case CegoObject::VIEW:
+		case CegoObject::RBSEG:
+		case CegoObject::PROCEDURE:
+		case CegoObject::JOIN:
+		case CegoObject::PBTREE:
+		case CegoObject::UBTREE:
+		case CegoObject::BTREE:
+		case CegoObject::TRIGGER:
+		case CegoObject::ALIAS:
+		case CegoObject::UNDEFINED:
 		{
 		    break;
 		}
@@ -1311,6 +1288,8 @@ void CegoDistDbHandler::getObjectByTableList(ListT<CegoTableObject>& idxList,
     {
 	throw Exception(EXLOC, Chain("Serial protocol still not supported"));
     }
+    */
+    throw Exception(EXLOC, Chain("No more supported"));
 }
 
 void CegoDistDbHandler::getPageCount(int& pageCount)
