@@ -2521,7 +2521,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoField *pF = to.getSchema().First();
 	while ( pF )
 	{
-	    if ( pF->getAttrName().length() > maxAttrLen )
+	    if ( (int)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = to.getSchema().Next();
 	}
@@ -2567,13 +2567,13 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoField *pF = io.getSchema().First();
 	while ( pF )
 	{
-	    if ( pF->getAttrName().length() > maxAttrLen )
+	    if ( (int)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = io.getSchema().Next();
 	}
 
 	int maxTabLen=10;	
-	if ( io.getTabName().length() > maxTabLen )
+	if ( (int)io.getTabName().length() > maxTabLen )
 	    maxTabLen = io.getTabName().length();
 	    
 	schema.Insert(CegoField(Chain("INDEXDESC"), Chain("TABLEDESC"), Chain("ATTR"), VARCHAR_TYPE, maxAttrLen));
@@ -2612,13 +2612,13 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoField *pF = bto.getSchema().First();
 	while ( pF )
 	{
-	    if ( pF->getAttrName().length() > maxAttrLen )
+	    if ( (int)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = bto.getSchema().Next();
 	}
 
 	int maxTabLen=10;	
-	if ( bto.getTabName().length() > maxTabLen )
+	if ( (int)bto.getTabName().length() > maxTabLen )
 	    maxTabLen = bto.getTabName().length();
 	    
 	schema.Insert(CegoField(Chain("BTREEDESC"), Chain("TABLEDESC"), Chain("ATTR"), VARCHAR_TYPE, maxAttrLen));
@@ -2655,7 +2655,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoField *pF = vo.getSchema().First();
 	while ( pF )
 	{
-	    if ( pF->getAttrName().length() > maxAttrLen )
+	    if ( (int)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = vo.getSchema().Next();
 	}
@@ -2697,7 +2697,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoProcVar *pArg = argList.First();
 	while ( pArg )
 	{
-	    if ( pArg->getName().length() > maxAttrLen )
+	    if ( (int)pArg->getName().length() > maxAttrLen )
 		maxAttrLen = pArg->getName().length();
 	    pArg = argList.Next();
 	}
@@ -2737,14 +2737,14 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	getDistObject(tableSet, objName, type, ko);
 	
 	int maxTabLen=10;
-	if ( objName.length() > maxTabLen )
+	if ( (int)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
 	int maxAttrLen=10;
 	CegoField *pK = ko.getKeySchema().First();
 	while ( pK )
 	{
-	    if ( pK->getAttrName().length() > maxAttrLen )
+	    if ( (int)pK->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pK->getAttrName().length();
 	    
 	    pK = ko.getKeySchema().Next();
@@ -2752,7 +2752,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoField *pR = ko.getRefSchema().First();
 	while ( pR )
 	{
-	    if ( pR->getAttrName().length() > maxAttrLen )
+	    if ( (int)pR->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pR->getAttrName().length();
 	    pR = ko.getRefSchema().Next();
 	}	
@@ -2797,7 +2797,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	int tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
 	int maxTabLen=10;
-	if ( objName.length() > maxTabLen )
+	if ( (int)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
 	int maxCheckLen=30;
@@ -2819,7 +2819,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	getDistObject(tableSet, objName, type, to);
 	
 	int maxTabLen=10;
-	if ( objName.length() > maxTabLen )
+	if ( (int)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
 	int maxCheckLen=30;
@@ -2841,7 +2841,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	getDistObject(tableSet, objName, type, ao);
 	
 	int maxTabLen=10;
-	if ( objName.length() > maxTabLen )
+	if ( (int)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
 	int maxAliasLen=30;
