@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -42,9 +42,15 @@ public:
 
     ~CegoFieldValue();
 
-    const CegoDataType getType() const;
+    Chain getId() const;
+	
+    void setNull();
+    
+    const CegoDataType& getType() const;
     void setType(const CegoDataType t);
 
+    int getDim() const;
+    
     void* getValue() const;
     int getLength() const;
 
@@ -62,7 +68,8 @@ public:
     bool operator >= ( const CegoFieldValue& fv) const;
 
     Comparison comp(const CegoFieldValue& fv) const;
-
+    static Comparison fastComp( CegoDataType t1, void* pV1, int l1, CegoDataType t2, void* pV2, int l2 );
+    
     friend CegoFieldValue operator + ( const CegoFieldValue& fv1, const CegoFieldValue& fv2);
     friend CegoFieldValue operator - ( const CegoFieldValue& fv1, const CegoFieldValue& fv2);
     friend CegoFieldValue operator * ( const CegoFieldValue& fv1, const CegoFieldValue& fv2);
@@ -91,7 +98,10 @@ public:
 
     int asInteger() const;
     long long asLong() const;
-
+    bool asBool() const;
+    
+    int usedMemory() const;
+    
 private:
 
     bool isEqual( const CegoFieldValue& fv2 ) const;
