@@ -78,7 +78,7 @@ void CegoFileHandler::setBackup(int fileId, bool m)
     {
 	_buMask[fileId] = new unsigned[ (  getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1];
 
-	int i;
+	unsigned long i;
 	
 	for (i = 0; i < ( getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1; i++)
 	{
@@ -287,7 +287,7 @@ void CegoFileHandler::initDataFile(int tabSetId, const Chain& path, int fileId,
 		
 	int i;
 	
-	for (i = 0; i < (numPages / (BIT_PER_BYTE * sizeof(unsigned))) + 1; i++)
+	for (i = 0; i < (int)((numPages / (BIT_PER_BYTE * sizeof(unsigned))) + 1); i++)
 	{
 	    unsigned bm = 0;
 	    pF->writeByte((char*)&bm, sizeof(unsigned));
@@ -335,7 +335,7 @@ void CegoFileHandler::resetDataFile(int fileId)
         
     int i;
     
-    for (i = 0; i < ( _numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned))) + 1; i++)
+    for (i = 0; i < (int)(( _numPages[fileId] / (BIT_PER_BYTE * sizeof(unsigned)))) + 1; i++)
     {
 	unsigned bm = 0;
 	pF->writeByte((char*)&bm, sizeof(unsigned));
@@ -514,7 +514,7 @@ void CegoFileHandler::readPage(PageIdType pageId, int& tabSetId, unsigned& fixSt
 	pF->readByte((char*)&fixStat, sizeof(unsigned));
 	
 	unsigned long rb = pF->readByte(pageData, _pageSize);
-	while ( rb < _pageSize )
+	while ( (int)rb < _pageSize )
 	{	  
 	    unsigned long rrb = pF->readByte((char*)((long long)pageData + rb), _pageSize - rb);
 	       
@@ -644,7 +644,7 @@ void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId
 		
 		// cout << "k=" << k << " numPages = " << _numPages[fid] << endl;
 
-		bool isEop = k >= _numPages[fid];
+		bool isEop = (int)k >= _numPages[fid];
 		
 		while (!isEop)
 		{
@@ -654,16 +654,16 @@ void CegoFileHandler::allocatePage(int tabSetId, FileType ft, PageIdType& pageId
 		    
 		    // printBitMap(bm);
 		       
-		    if ( (bm & ~0) != ~0) 
+		    if ( (bm & ~0) != (unsigned)~0) 
 		    {
 			// we start next append search with this fid
 			_appendFid = fid;
 
 			// free page available
-			int l = 0;
+			unsigned l = 0;
 			while (l < ws && ! isEop)
 			{
-			    if ( k+l < _numPages[fid])
+			    if ( (int)(k+l) < _numPages[fid])
 			    {
 				unsigned checkbit = bm >> l & ~(~(unsigned)0 << 1);
 				if (checkbit == 0)
@@ -845,7 +845,7 @@ void CegoFileHandler::commitPageEntry(PageIdType pageId)
 
 	int i;
 	
-	for (i = 0; i < ( getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1; i++)
+	for (i = 0; i < (int)(( getNumPages(fileId) / (BIT_PER_BYTE * sizeof(unsigned))) + 1); i++)
 	{
 	    _commitMask[fileId][i] = 0;
 	}
@@ -960,7 +960,7 @@ int CegoFileHandler::getNumUsedPages(int fileId, CegoLockHandler *pLockHandle)
 	
 	int usedPages = 0;
 
-	for ( p = 0; p < (numPage / (BIT_PER_BYTE * sizeof(unsigned))) + 1; p++ )
+	for ( p = 0; p < (int)((numPage / (BIT_PER_BYTE * sizeof(unsigned))) + 1); p++ )
 	{
 	    unsigned bm = 0;
 	    pF->readByte((char*)&bm, sizeof(unsigned));
@@ -968,7 +968,7 @@ int CegoFileHandler::getNumUsedPages(int fileId, CegoLockHandler *pLockHandle)
 	    // printBitMap(bm);
 	    
 	    int i,j;
-	    for (i = 0; i< sizeof(unsigned); i++)
+	    for (i = 0; i< (int)sizeof(unsigned); i++)
 	    {
 		for (j=0; j < BIT_PER_BYTE; j++)
 		{
@@ -1120,7 +1120,7 @@ void CegoFileHandler::printBitMap(unsigned bm)
     printf("--- BM -----------\n");
     
     int i,j;
-    for (i = 0; i< sizeof(unsigned); i++)
+    for (i = 0; i< (int)sizeof(unsigned); i++)
     {
 	for (j=0; j < BIT_PER_BYTE; j++)
 	{
@@ -1144,7 +1144,7 @@ int CegoFileHandler::mapDiff(unsigned bm1, unsigned bm2)
     int numDiff = 0;
     
     int i,j;
-    for (i = 0; i< sizeof(unsigned); i++)
+    for (i = 0; i< (int)sizeof(unsigned); i++)
     {
 	for (j=0; j < BIT_PER_BYTE; j++)
 	{
