@@ -483,7 +483,8 @@ int CegoFunction::getReturnTypeLen(const ListT<CegoField>& fl)
     case SUBSTR:
     {
 	CegoExpr** pSourceExpr = _exprList.First();
-	CegoExpr** pOffsetExpr = _exprList.Next(); // not used
+	// CegoExpr** pOffsetExpr =
+	_exprList.Next(); // not used
 	CegoExpr** pLengthExpr = _exprList.Next();
 	if ( pLengthExpr )
 	{	    
@@ -1178,7 +1179,7 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	// len = *((int*)fv2.getValue());
 			
 	Chain right;
-	if ( len < fv1.valAsChain().length() )
+	if ( len < (int)fv1.valAsChain().length() )
 	    right = fv1.valAsChain().subChain(fv1.valAsChain().length() - len, fv1.valAsChain().length());
 	else
 	    right = fv1.valAsChain();
@@ -1208,7 +1209,7 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	// len = *((int*)fv2.getValue());
 	
 	Chain left;
-	if ( len < fv1.valAsChain().length() )
+	if ( len < (int)fv1.valAsChain().length() )
 	    left = fv1.valAsChain().subChain(1, len);
 	else
 	    left = fv1.valAsChain();
@@ -1281,13 +1282,13 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	    start = 1;
 
 	// we start at max s.length()
-	if ( start > s.length() )
+	if ( start > (int)s.length() )
 	{
 	    start = s.length();
 	    // throw Exception(EXLOC, "Start postion after end");
 	}
 		
-	if ( start+len-1 > s.length())
+	if ( start+len-1 > (int)s.length())
 	{
 	    len = s.length() - start;
 	    // throw Exception(EXLOC, "End postion after end");
