@@ -6,7 +6,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -21,10 +21,6 @@
 //
 ///////////////////////////////////////////////////////////////////////////////
 
-#ifndef _REENTRANT
-#define _REENTRANT    /* basic 3-lines for threads */
-#endif
-
 // LFC INCLUDES
 #include <lfcbase/Exception.h>
 #include <lfcbase/ThreadLock.h>
@@ -47,14 +43,12 @@ CegoLockHandler::CegoLockHandler(CegoDatabaseManager* pDBMng)
     _numRecSema = pDBMng->getNumRecordSema();
     _numRBRecSema = pDBMng->getNumRBRecordSema();
     _numSysRecSema = pDBMng->getNumSysRecordSema();
-
     _numSysPageSema = pDBMng->getNumSysPageSema();
     _numDataPageSema = pDBMng->getNumDataPageSema();
     _numIdxPageSema = pDBMng->getNumIndexPageSema();
     _numRBPageSema = pDBMng->getNumRBPageSema();
     _numDataFileSema = pDBMng->getNumDataFileSema();
     _numBufferPoolSema = pDBMng->getNumBufferPoolSema();
-
     _pageLockTimeout = pDBMng->getPageLockTimeout();
     _recLockTimeout = pDBMng->getRecLockTimeout();
     _fileLockTimeout = pDBMng->getFileLockTimeout();
@@ -79,7 +73,6 @@ CegoLockHandler::CegoLockHandler(CegoDatabaseManager* pDBMng)
     _recordLock = (RecordLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct RecordLock));
     _rbRecordLock = (RecordLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct RecordLock));
     _sysRecordLock = (RecordLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct RecordLock));
-
     _sysPageLock = (PageLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct PageLock));
     _dataPageLock = (PageLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct PageLock));
     _idxPageLock = (PageLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct PageLock));
@@ -94,30 +87,20 @@ CegoLockHandler::CegoLockHandler(CegoDatabaseManager* pDBMng)
     {
 	_recordLock[i].semId=0;
 	_recordLock[i].lockId=0;
-
 	_rbRecordLock[i].semId=0;
 	_rbRecordLock[i].lockId=0;
-
 	_sysRecordLock[i].semId=0;
 	_sysRecordLock[i].lockId=0;
-
 	_sysPageLock[i].lockId=0;
-	_sysPageLock[i].fileId=0;
 	_sysPageLock[i].pageId=0;
 	_sysPageLock[i].semId=0;
-
 	_dataPageLock[i].lockId=0;
-	_dataPageLock[i].fileId=0;
 	_dataPageLock[i].pageId=0;
 	_dataPageLock[i].semId=0;
-
 	_idxPageLock[i].lockId=0;
-	_idxPageLock[i].fileId=0;
 	_idxPageLock[i].pageId=0;
 	_idxPageLock[i].semId=0;
-
 	_rbPageLock[i].lockId=0;
-	_rbPageLock[i].fileId=0;
 	_rbPageLock[i].pageId=0;
 	_rbPageLock[i].semId=0;		
     }
@@ -130,7 +113,6 @@ CegoLockHandler::~CegoLockHandler()
     delete _recordLock;
     delete _rbRecordLock;
     delete _sysRecordLock;
-
     delete _sysPageLock;
     delete _dataPageLock;
     delete _idxPageLock;
@@ -139,7 +121,6 @@ CegoLockHandler::~CegoLockHandler()
 
 void CegoLockHandler::initLocks()
 {
-
     _lockArray = new ThreadLock*[_numSema];
 
     for (int i = 0; i<_numSema; i++)
@@ -186,7 +167,6 @@ void CegoLockHandler::initLocks()
 	+ _numSysRecSema
 	+ _numSysPageSema;
 
-
     for (  semId = low ; semId < high ; semId++ )
     {
 	_lockArray[semId]->setId( Chain(SYSPAGELOCKGROUP) + Chain("-") + Chain(semId-low));
@@ -286,8 +266,7 @@ void CegoLockHandler::initLocks()
     for (  semId = low ; semId < high ; semId++ )
     {
 	_lockArray[semId]->setId( Chain(POOLLOCKGROUP) + Chain("-") + Chain(semId-low));
-    }
-    
+    }    
 }
 
 void CegoLockHandler::deleteLocks()
@@ -303,14 +282,13 @@ void CegoLockHandler::deleteLocks()
 
 unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum LockMode lockMode)
 {
-
     int timeout = _recLockTimeout;
     int numTries = _numLockTries;
 
-    int semId = ( dp.getFileId() * dp.getPageId() + dp.getOffset()) % _numRecSema;
+    int semId = ( dp.getPageId() + dp.getOffset()) % _numRecSema;
 
     int i=0;
-    while ( _recordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
+    while ( _recordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS )
     {
 	i++;
     }
@@ -327,7 +305,7 @@ unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum L
 	while ( numTries > 0 )
 	{
 	    try
-	    {		
+	    {
 		if ( lockMode == READ )
 		    _lockArray[semId]->readLock(timeout);
 		else
@@ -349,9 +327,7 @@ unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum L
 			lockMode = Chain("Write lock");
 
 
-		    Chain msg = lockMode + Chain(" for record failed, fileId ") 
-			+ Chain(dp.getFileId())
-			+ Chain(" pageid ") + Chain(dp.getPageId()) + Chain(", offset ") + Chain(dp.getOffset()) + Chain(", reason ") + lockError; 
+		    Chain msg = lockMode + Chain(" for record failed, pageid ") + Chain(dp.getPageId()) + Chain(", offset ") + Chain(dp.getOffset()) + Chain(", reason ") + lockError; 
 
 		    throw Exception(EXLOC, msg, e);
 		}
@@ -361,7 +337,6 @@ unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum L
 		}
 	    }
 	}
-
 	_lockCount[semId]++;
     }
     else
@@ -369,21 +344,18 @@ unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum L
 	_lockCount[semId]++;
     }
         
-    return _recordLock[i].lockId;
-    
+    return _recordLock[i].lockId;    
 }
 
 void CegoLockHandler::unlockRecord(unsigned long long lockId)
 {
-
     int i=0;
     while (i < LCKMNG_NUMLOCKS && _recordLock[i].lockId != lockId )
     {
 	i++;
     }
-    if (_recordLock[i].lockId == lockId)
-    {
-	
+    if ( _recordLock[i].lockId == lockId )
+    {	
 	int semId = _recordLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
@@ -407,12 +379,10 @@ void CegoLockHandler::unlockRecord(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockRBRecord(const CegoDataPointer& dp, enum LockMode lockMode)
 {
-
     int timeout = _recLockTimeout;
     int numTries = _numLockTries;
 
-    int semId = _numRecSema
-	+ ( dp.getFileId() * dp.getPageId() + dp.getOffset()) % _numRBRecSema;
+    int semId = _numRecSema + ( dp.getPageId() + dp.getOffset()) % _numRBRecSema;
 
     int i=0;
     while ( _rbRecordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
@@ -454,9 +424,7 @@ unsigned long long CegoLockHandler::lockRBRecord(const CegoDataPointer& dp, enum
 			lockMode = Chain("Write lock");
 
 
-		    Chain msg = lockMode + Chain(" for rb record failed, fileId ") 
-			+ Chain(dp.getFileId())
-			+ Chain(" pageid ") + Chain(dp.getPageId()) + Chain(", offset ") + Chain(dp.getOffset()) + Chain(", reason ") + lockError; 
+		    Chain msg = lockMode + Chain(" for rb record failed, pageid ") + Chain(dp.getPageId()) + Chain(", offset ") + Chain(dp.getOffset()) + Chain(", reason ") + lockError; 
 
 		    throw Exception(EXLOC, msg, e);
 		}
@@ -466,29 +434,24 @@ unsigned long long CegoLockHandler::lockRBRecord(const CegoDataPointer& dp, enum
 		}
 	    }
 	}
-
 	_lockCount[semId]++;
     }
     else
     {
 	_lockCount[semId]++;
     }
-        
     return _rbRecordLock[i].lockId;
-    
 }
 
 void CegoLockHandler::unlockRBRecord(unsigned long long lockId)
 {
-
     int i=0;
     while (i < LCKMNG_NUMLOCKS && _rbRecordLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_rbRecordLock[i].lockId == lockId)
-    {
-	
+    {	
 	int semId = _rbRecordLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
@@ -512,13 +475,12 @@ void CegoLockHandler::unlockRBRecord(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockSysRecord(const CegoDataPointer& dp, enum LockMode lockMode)
 {
-
     int timeout = _recLockTimeout;
     int numTries = _numLockTries;
 
     int semId = _numRecSema
 	+ _numRBRecSema
-	+ ( dp.getFileId() * dp.getPageId() + dp.getOffset()) % _numSysRecSema;
+	+ ( dp.getPageId() + dp.getOffset()) % _numSysRecSema;
 
     int i=0;
     while ( _sysRecordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
@@ -559,10 +521,7 @@ unsigned long long CegoLockHandler::lockSysRecord(const CegoDataPointer& dp, enu
 		    else
 			lockMode = Chain("Write lock");
 
-
-		    Chain msg = lockMode + Chain(" for sys record failed, fileId ") 
-			+ Chain(dp.getFileId())
-			+ Chain(" pageid ") + Chain(dp.getPageId()) + Chain(", offset ") + Chain(dp.getOffset()) + Chain(", reason ") + lockError; 
+		    Chain msg = lockMode + Chain(" for sys record failed, pageid ") + Chain(dp.getPageId()) + Chain(", offset ") + Chain(dp.getOffset()) + Chain(", reason ") + lockError; 
 
 		    throw Exception(EXLOC, msg, e);
 		}
@@ -572,29 +531,25 @@ unsigned long long CegoLockHandler::lockSysRecord(const CegoDataPointer& dp, enu
 		}
 	    }
 	}
-
 	_lockCount[semId]++;
     }
     else
     {
 	_lockCount[semId]++;
     }
-        
-    return _sysRecordLock[i].lockId;
     
+    return _sysRecordLock[i].lockId;    
 }
 
 void CegoLockHandler::unlockSysRecord(unsigned long long lockId)
 {
-
     int i=0;
     while (i < LCKMNG_NUMLOCKS && _sysRecordLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_sysRecordLock[i].lockId == lockId)
-    {
-	
+    {	
 	int semId = _sysRecordLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
@@ -616,13 +571,12 @@ void CegoLockHandler::unlockSysRecord(unsigned long long lockId)
     }
 }
 
-unsigned long long CegoLockHandler::lockSysPage(int fileId, int pageId, enum LockMode lockMode)
+unsigned long long CegoLockHandler::lockSysPage(PageIdType pageId, enum LockMode lockMode)
 {
-
     int semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema 
-	+ ( fileId * ( pageId + 1 ) )  % _numSysPageSema;
+	+ pageId % _numSysPageSema;
 
     int timeout = _pageLockTimeout;
     int numTries = _numLockTries;
@@ -641,7 +595,6 @@ unsigned long long CegoLockHandler::lockSysPage(int fileId, int pageId, enum Loc
 
     if ( _lockCount[semId] == 0 )
     {
-
 	while ( numTries > 0 )
 	{
 	    try
@@ -654,7 +607,6 @@ unsigned long long CegoLockHandler::lockSysPage(int fileId, int pageId, enum Loc
 	    }
 	    catch ( Exception e )
 	    {		
-
 		numTries--;									
 		if ( numTries == 0 )
 		{
@@ -667,7 +619,7 @@ unsigned long long CegoLockHandler::lockSysPage(int fileId, int pageId, enum Loc
 		    else
 			lockMode = Chain("Write lock");
 
-		    Chain msg = lockMode + Chain(" for sys page failed, fileid ") + Chain(fileId) + Chain(", pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
+		    Chain msg = lockMode + Chain(" for sys page failed, pageId ") + Chain(pageId) + Chain(", reason ") + lockError;
 		    throw Exception(EXLOC, msg, e);
 		}
 		else
@@ -685,7 +637,6 @@ unsigned long long CegoLockHandler::lockSysPage(int fileId, int pageId, enum Loc
     }
     
     _sysPageLock[i].semId=semId;    
-    _sysPageLock[i].fileId = fileId;
     _sysPageLock[i].pageId = pageId;
     
     return _sysPageLock[i].lockId;    
@@ -693,7 +644,6 @@ unsigned long long CegoLockHandler::lockSysPage(int fileId, int pageId, enum Loc
 
 void CegoLockHandler::unlockSysPage(unsigned long long lockId)
 {
-
     int i=0;
     while (i < LCKMNG_NUMLOCKS && _sysPageLock[i].lockId != lockId )
     {
@@ -722,21 +672,21 @@ void CegoLockHandler::unlockSysPage(unsigned long long lockId)
     }
 }
 
-unsigned long long CegoLockHandler::lockData(CegoObject::ObjectType type, int fileId, int pageId, enum LockMode lockMode)
-{   
+unsigned long long CegoLockHandler::lockData(CegoObject::ObjectType type, PageIdType pageId, enum LockMode lockMode)
+{
     if ( type == CegoObject::AVLTREE || type == CegoObject::UAVLTREE || type == CegoObject::PAVLTREE || type == CegoObject::BTREE || type == CegoObject::UBTREE || type == CegoObject::PBTREE )
     {
-	return lockIndexPage(fileId, pageId, lockMode);
+	return lockIndexPage(pageId, lockMode);
     }
     else if ( type == CegoObject::RBSEG )
     {
-	return lockRBPage(fileId, pageId, lockMode);
+	return lockRBPage(pageId, lockMode);
     }
-    return lockDataPage(fileId, pageId, lockMode);
+    return lockDataPage(pageId, lockMode);
 }
 
 void CegoLockHandler::unlockData(CegoObject::ObjectType type, unsigned long long lockId)
-{    
+{   
     if ( type == CegoObject::AVLTREE || type == CegoObject::UAVLTREE || type == CegoObject::PAVLTREE || type == CegoObject::BTREE || type == CegoObject::UBTREE || type == CegoObject::PBTREE )
     {
 	return unlockIndexPage(lockId);
@@ -748,14 +698,13 @@ void CegoLockHandler::unlockData(CegoObject::ObjectType type, unsigned long long
     return unlockDataPage(lockId);
 }
 
-unsigned long long CegoLockHandler::lockDataPage(int fileId, int pageId, enum LockMode lockMode)
+unsigned long long CegoLockHandler::lockDataPage(PageIdType pageId, enum LockMode lockMode)
 {
-
     int semId = _numRecSema 
 	+ _numRBRecSema
 	+ _numSysRecSema 
 	+ _numSysPageSema 
-	+ ( fileId * ( pageId + 1 ) )  % _numDataPageSema;
+	+ ( pageId % _numDataPageSema );
 
     int timeout = _pageLockTimeout;
     int numTries = _numLockTries;
@@ -798,7 +747,7 @@ unsigned long long CegoLockHandler::lockDataPage(int fileId, int pageId, enum Lo
 		    else
 			lockMode = Chain("Write lock");
 
-		    Chain msg = lockMode + Chain(" for data page failed, fileid ") + Chain(fileId) + Chain(", pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
+		    Chain msg = lockMode + Chain(" for data page failed, pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
 
 		    throw Exception(EXLOC, msg, e);
 		}
@@ -816,8 +765,7 @@ unsigned long long CegoLockHandler::lockDataPage(int fileId, int pageId, enum Lo
 	_lockCount[semId]++;
     }
 
-    _dataPageLock[i].semId=semId;    
-    _dataPageLock[i].fileId = fileId;
+    _dataPageLock[i].semId=semId;
     _dataPageLock[i].pageId = pageId;
 
     return _dataPageLock[i].lockId;    
@@ -853,15 +801,14 @@ void CegoLockHandler::unlockDataPage(unsigned long long lockId)
     }
 }
 
-unsigned long long CegoLockHandler::lockIndexPage(int fileId, int pageId, enum LockMode lockMode)
+unsigned long long CegoLockHandler::lockIndexPage(PageIdType pageId, enum LockMode lockMode)
 {
-
     int semId = _numRecSema
 	+ _numRBRecSema 
 	+ _numSysRecSema
 	+ _numSysPageSema 
 	+ _numDataPageSema 
-	+ ( fileId * ( pageId + 1 ) )  % _numIdxPageSema;
+	+ ( pageId  % _numIdxPageSema );
 
     int timeout = _pageLockTimeout;
     int numTries = _numLockTries;
@@ -904,7 +851,7 @@ unsigned long long CegoLockHandler::lockIndexPage(int fileId, int pageId, enum L
 		    else
 			lockMode = Chain("Write lock");
 		    
-		    Chain msg = lockMode + Chain(" for index page failed, fileid ") + Chain(fileId) + Chain(", pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
+		    Chain msg = lockMode + Chain(" for index page failed, pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
 
 		    throw Exception(EXLOC, msg, e);
 		}
@@ -923,7 +870,6 @@ unsigned long long CegoLockHandler::lockIndexPage(int fileId, int pageId, enum L
     }
 
     _idxPageLock[i].semId=semId;    
-    _idxPageLock[i].fileId = fileId;
     _idxPageLock[i].pageId = pageId;
 
     return _idxPageLock[i].lockId;   
@@ -959,16 +905,15 @@ void CegoLockHandler::unlockIndexPage(unsigned long long lockId)
     }
 }
 
-unsigned long long CegoLockHandler::lockRBPage(int fileId, int pageId, enum LockMode lockMode)
+unsigned long long CegoLockHandler::lockRBPage(PageIdType pageId, enum LockMode lockMode)
 {
-
     int semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema
 	+ _numSysPageSema 
 	+ _numDataPageSema 
 	+ _numIdxPageSema 
-	+ ( fileId * ( pageId + 1 ) )  % _numRBPageSema;
+	+ ( pageId % _numRBPageSema );
 
     int timeout = _pageLockTimeout;
     int numTries = _numLockTries;
@@ -987,7 +932,6 @@ unsigned long long CegoLockHandler::lockRBPage(int fileId, int pageId, enum Lock
 
     if ( _lockCount[semId] == 0 )
     {
-
 	while ( numTries > 0 )
 	{
 	    try
@@ -1013,7 +957,7 @@ unsigned long long CegoLockHandler::lockRBPage(int fileId, int pageId, enum Lock
 		    else
 			lockMode = Chain("Write lock");
 		    
-		    Chain msg = lockMode + Chain(" for rb page failed, fileid ") + Chain(fileId) + Chain(", pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
+		    Chain msg = lockMode + Chain(" for rb page failed, pageid ") + Chain(pageId) + Chain(", reason ") + lockError;
 
 		    throw Exception(EXLOC, msg, e);
 		}
@@ -1032,17 +976,13 @@ unsigned long long CegoLockHandler::lockRBPage(int fileId, int pageId, enum Lock
     }
 
     _rbPageLock[i].semId=semId;    
-    _rbPageLock[i].fileId = fileId;
     _rbPageLock[i].pageId = pageId;
 
-
     return _rbPageLock[i].lockId;
-    
 }
 
 void CegoLockHandler::unlockRBPage(unsigned long long lockId)
 {
-
     int i=0;
     while (i < LCKMNG_NUMLOCKS && _rbPageLock[i].lockId != lockId )
     {
@@ -1073,7 +1013,6 @@ void CegoLockHandler::unlockRBPage(unsigned long long lockId)
 
 void CegoLockHandler::lockDataFile(int fileId, enum LockMode lockMode)
 {
-
     int semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema 
@@ -1088,7 +1027,6 @@ void CegoLockHandler::lockDataFile(int fileId, enum LockMode lockMode)
 
     if ( _lockCount[semId] == 0 )
     {
-
 	while ( numTries > 0 )
 	{
 	    try
@@ -1106,7 +1044,6 @@ void CegoLockHandler::lockDataFile(int fileId, enum LockMode lockMode)
 		numTries--;
 		if ( numTries == 0 )
 		{
-
 		    Chain lockError;
 		    e.pop(lockError);
 
@@ -1158,8 +1095,8 @@ void CegoLockHandler::unlockDataFile(int fileId)
 }
 
 void CegoLockHandler::lockBufferPool(int hashId, enum LockMode lockMode)
-{
-
+{    
+    
     int semId = _numRecSema
 	+ _numRBRecSema 
 	+ _numSysRecSema
@@ -1172,17 +1109,22 @@ void CegoLockHandler::lockBufferPool(int hashId, enum LockMode lockMode)
 
     int timeout = _poolLockTimeout;
     int numTries = _numLockTries;
-
+    
     if ( _lockCount[semId] == 0 )
     {
 	while ( numTries > 0 )
 	{
 	    try
-	    {		
+	    {
 		if ( lockMode == READ )
+		{
 		    _lockArray[semId]->readLock(timeout);
-		else 
-		    _lockArray[semId]->writeLock(timeout);				
+		}
+		else
+		{
+		    _lockArray[semId]->writeLock(timeout);
+		}
+				
 		numTries=0;
 	    }
 	    catch ( Exception e )
@@ -1212,13 +1154,13 @@ void CegoLockHandler::lockBufferPool(int hashId, enum LockMode lockMode)
     }
     else
     {
+	// _pDBMng->log(_modId, Logger::NOTICE, Chain("Increasing bufferpool lockcount for ") + Chain(semId) + Chain(" from  ") + Chain(_lockCount[semId]));
 	_lockCount[semId]++;
     }    
 }
 
 void CegoLockHandler::unlockBufferPool(int hashId)
 {
-
     int semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema
@@ -1229,32 +1171,41 @@ void CegoLockHandler::unlockBufferPool(int hashId)
 	+ _numDataFileSema 
 	+ hashId % _numBufferPoolSema;
 
-    if ( _lockCount[semId] == 1 )
+    if ( _lockCount[semId] > 1 )
     {
-	_lockArray[semId]->unlock();
+	// _pDBMng->log(_modId, Logger::NOTICE, Chain("Decreasing bufferpool lockcount for ") + Chain(semId) + Chain(" from  ") + Chain(_lockCount[semId]));
 	_lockCount[semId]--;
     }
-    else
+    else 
     {
-	_lockCount[semId]--;
+	_lockArray[semId]->unlock();
+	_lockCount[semId] = 0;
     }
 }
 
+/*
+  the method lockBufferPool tries to lock the whole bufferpool.
+  In case of any locking error, we have to save the currect lock position, since later on
+  we just have to unlock to this position */
+ 
 void CegoLockHandler::lockBufferPool()
 {
+    _poolLockRange=0;
     for ( int i=0; i<_numBufferPoolSema; i++ )
-	lockBufferPool(i, WRITE);
+    {
+	lockBufferPool(_poolLockRange, WRITE);
+	_poolLockRange=i+1;
+    }
 }
 
 void CegoLockHandler::unlockBufferPool()
 {
-    for ( int i=0; i<_numBufferPoolSema; i++ )
+    for ( int i=0; i<_poolLockRange; i++ )
 	unlockBufferPool(i);
 }
 
 void CegoLockHandler::getLockStat(int semId, Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
-{
-    
+{   
     lockName = _lockArray[semId]->getId();
     lockCount = _lockArray[semId]->numLockTry();
     numRdLock = _lockArray[semId]->numReadLock();
@@ -1266,12 +1217,10 @@ void CegoLockHandler::getLockStat(int semId, Chain& lockName, int& lockCount, un
 	sumRdDelay = _lockArray[semId]->sumReadDelay() / LCKMNG_DELRES;   
     if ( _lockArray[semId]->numWriteLock() > 0 )
 	sumWrDelay = _lockArray[semId]->sumWriteDelay() / LCKMNG_DELRES;
-
 }
 
 void CegoLockHandler::getAggLockStat(const Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
-
     lockCount = 0;
     numRdLock = 0;
     numWrLock = 0;
@@ -1280,8 +1229,7 @@ void CegoLockHandler::getAggLockStat(const Chain& lockGroup, int& numLock, int&
     numLock = 0;
 
     for ( int semId=0; semId<_numSema; semId++ )
-    {
-	
+    {	
 	Tokenizer tok(_lockArray[semId]->getId(), "-");
 	
 	Chain checkGroup;
