@@ -115,14 +115,14 @@ int main(int argc, char **argv)
 
 	
 	int offset;
-	int c = pLog->readByte((char*)&offset, sizeof(int));	
+	pLog->readByte((char*)&offset, sizeof(int));	
 	
 	int pos = sizeof(int);
 	       
 	while (pos < offset)
 	{
 	    int len;
-	    c = pLog->readByte((char*)&len, sizeof(int));	
+	    pLog->readByte((char*)&len, sizeof(int));	
 	    
 	    // cout << "Read len : " << len << endl;
 	    
