@@ -450,14 +450,14 @@ void CegoLogThreadPool::copyLog(const Chain& tableSet, const Chain& logFileName,
     logFile.open(File::READ);
 
     int offset;
-    int c = logFile.readByte((char*)&offset, sizeof(int));
+    logFile.readByte((char*)&offset, sizeof(int));
 
     int pos = sizeof(int);
 
     if ( pos < offset)
     {	
 	int len;
-	c = logFile.readByte((char*)&len, sizeof(int));	
+	logFile.readByte((char*)&len, sizeof(int));	
 	
 	char* buf = new char[len];
 	
