@@ -130,7 +130,7 @@
 #define DEFAULTTSROOT "./"
 #define DEFAULTHOST "localhost"
 #define DEFAULTPIDFILE "./pid"
-#define DEFAULTPAGESIZE 8192
+#define DEFAULTPAGESIZE 16384
 #define DEFAULTDBPORT 2200
 #define DEFAULTADMPORT 2000
 #define DEFAULTLOGPORT 3000
@@ -827,7 +827,8 @@ int defineTableSet(GetLongOpt& longOpt)
 	int logFileNum = DEFAULTLOGNUM;
 	
 	long orderSize = DEFAULTORDERSIZE;
-
+	int branchId = 0;
+	
 	Tokenizer atok(tsDef, Chain(","));
 	
 	Chain attrTup;
@@ -853,6 +854,8 @@ int defineTableSet(GetLongOpt& longOpt)
 		tsRoot = value;
 	    else if ( attr == Chain("sortareasize"))
 		orderSize = value.asLong();
+	    else if ( attr == Chain("branchid"))
+		branchId = value.asInteger();
 	}
 	
 	int sysFid = pDBMng->nextTSID();
@@ -874,7 +877,8 @@ int defineTableSet(GetLongOpt& longOpt)
 			       appSize,
 			       logFileSize, 
 			       logFileNum,
-			       orderSize); 
+			       orderSize,
+			       branchId); 
 	       	
 	pDBMng->doc2Xml();
 	
