@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -20,6 +20,7 @@
 
 // CEGO INCLUDES
 #include "CegoObject.h"
+
 // POSIX INCLUDES
 #include <string.h>
 
@@ -77,7 +78,6 @@ int CegoObject::getTabSetId() const
 
 int CegoObject::getBaseSize() const
 {
-
     int baseSize = sizeof(int); // entrySize
 
     baseSize += 1; // object type
@@ -89,7 +89,7 @@ int CegoObject::getBaseSize() const
     return baseSize;
 }
 
-void CegoObject::encodeBase(char *buf, int entrySize)
+void CegoObject::encodeBase(char *buf, int entrySize) const
 {
     char* bufPtr = buf;
     
@@ -132,21 +132,6 @@ void CegoObject::decodeBase(char *buf, int& entrySize)
     memcpy(&_tabSetId, bufPtr, sizeof(int));
 }
 
-CegoObject& CegoObject::operator = ( const CegoObject& oe)
-{
-    _type = oe._type;
-    _name = oe._name;
-    _tabSetId = oe._tabSetId;
-    return (*this);
-}
-
-bool CegoObject::operator == ( const CegoObject& oe)
-{
-    if ( _name == oe._name && _type == oe._type && _tabSetId == oe._tabSetId)
-	return true;
-    return false;
-}
-
 int CegoObject::size() const
 {
     return _name.length() + sizeof(ObjectType) + sizeof(int);
@@ -198,6 +183,12 @@ Chain CegoObject::toChain() const
     case CHECK:
 	s += Chain("check");
 	break;
+    case TRIGGER:
+	s += Chain("trigger");
+	break;
+    case ALIAS:
+	s += Chain("alias");
+	break;
     case JOIN:
 	s += Chain("join");
 	break;
@@ -209,3 +200,18 @@ Chain CegoObject::toChain() const
     s += "TableSetId: " + Chain(_tabSetId) + Chain("\n");
     return s;
 }
+
+CegoObject& CegoObject::operator = ( const CegoObject& oe)
+{
+    _type = oe._type;
+    _name = oe._name;
+    _tabSetId = oe._tabSetId;
+    return (*this);
+}
+
+bool CegoObject::operator == ( const CegoObject& oe)
+{
+    if ( _name == oe._name && _type == oe._type && _tabSetId == oe._tabSetId)
+	return true;
+    return false;
+}
