@@ -6,7 +6,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -29,26 +29,18 @@ CegoObjectCursor::CegoObjectCursor()
 CegoObjectCursor::CegoObjectCursor(CegoBufferPool *pBufPool, CegoLockHandler *pLockHandle, 
 				   int tabSetId, 
 				   CegoObject::ObjectType type, 
-				   int fileId, int pageId)
+				   PageIdType pageId)
 {
     _pBufPool = pBufPool;
     _pLockHandle = pLockHandle;
-
-    _tabSetId = tabSetId;
-
-    _fileId = fileId;
-    _pageId = pageId;
-
-    _startFileId = fileId;
+    _tabSetId = tabSetId;    
+    _pageId = pageId;   
     _startPageId = pageId;
-    
     _type = type;
-    
     _lockId = 0;
     _recLock = 0;
-    
-    _isEOC = false;
-
+    _isEOC = ( pageId == 0 );
+    _lastPageSync = false;
     _modId = _pBufPool->getModId("CegoObjectCursor");
 }
 
@@ -62,19 +54,23 @@ int CegoObjectCursor::getTabSetId()
     return _tabSetId;
 }
 
+void CegoObjectCursor::setLastPageSync(bool doSync)
+{
+    _lastPageSync = doSync;
+}
+
 void* CegoObjectCursor::getFirst(int& len, CegoDataPointer& dp)
 {
-
     if ( _isEOC )
 	return 0;
     
-    try {
-	
-	_pBufPool->bufferFix(_bp,_tabSetId, _fileId, _pageId, CegoBufferPool::SYNC, _pLockHandle);
+    try
+    {	
+	_pBufPool->bufferFix(_bp,_tabSetId, _pageId, CegoBufferPool::SYNC, _pLockHandle);
 	
 	try
 	{
-	    _lockId = _pLockHandle->lockData(_type, _fileId, _pageId, CegoLockHandler::READ);
+	    _lockId = _pLockHandle->lockData(_type, _pageId, CegoLockHandler::READ);
 	}
 	catch ( Exception e)
 	{
@@ -83,44 +79,42 @@ void* CegoObjectCursor::getFirst(int& len, CegoDataPointer& dp)
 	    
 	    _lockId = 0;
 	    
-	    _pBufPool->log(_modId, Logger::LOGERR, Chain("Data page lock error for fileId=") 
-			   + Chain(_fileId) + Chain(" pageId=") + Chain(_pageId) + Chain(" : ") +  msg);		
+	    _pBufPool->log(_modId, Logger::LOGERR, Chain("Data page lock error for pageId=") + Chain(_pageId) + Chain(" : ") +  msg);		
 	    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
 	    throw Exception(EXLOC, msg);
 	}
 	
 	if ( void* p = _bp.getFirstEntry() )
 	{
-	    dp.setFileId(_fileId);
 	    dp.setPageId(_pageId);
-	    
+	    dp.setOffset(_bp.getEntryPos());	    
 	    len = _bp.getEntryLen();
-	    dp.setOffset(_bp.getEntryPos());
-
 	    return p;
 	}
 	else
 	{	
-	    _pLockHandle->unlockData(_type, _lockId);    
-	    _lockId = 0;
-	    
-	    _fileId = _bp.getNextFileId();
 	    _pageId = _bp.getNextPageId();
 	    
+	    // keep last page in sync ?
+	    if ( ! ( _lastPageSync && _pageId == 0 ) )
+	    {
+		_pLockHandle->unlockData(_type, _lockId);    
+		_lockId = 0;
+	    }
+	   	   
 	    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
 	    
-	    while ( ! ( _fileId == 0 && _pageId == 0 ) )
-	    {
-		
+	    while ( ! ( _pageId == 0 ) )
+	    {		
 		CegoBufferPage nbp;						
 		
-		_pBufPool->bufferFix(nbp, _tabSetId, _fileId, _pageId, CegoBufferPool::SYNC, _pLockHandle);
+		_pBufPool->bufferFix(nbp, _tabSetId, _pageId, CegoBufferPool::SYNC, _pLockHandle);
 		
 		_bp = nbp;
 		
 		try
 		{
-		    _lockId = _pLockHandle->lockData(_type, _fileId, _pageId, CegoLockHandler::READ);
+		    _lockId = _pLockHandle->lockData(_type, _pageId, CegoLockHandler::READ);
 		}
 		catch ( Exception e)
 		{
@@ -128,34 +122,31 @@ void* CegoObjectCursor::getFirst(int& len, CegoDataPointer& dp)
 		    
 		    Chain msg;
 		    e.pop(msg);			    
-		    _pBufPool->log(_modId, Logger::LOGERR, Chain("Data page lock error for fileId=") 
-				   + Chain(_fileId) + Chain(" pageId=") + Chain(_pageId) + Chain(" : ") +  msg);		
-		    
-		    
+		    _pBufPool->log(_modId, Logger::LOGERR, Chain("Data page lock error for pageId=") + Chain(_pageId) + Chain(" : ") +  msg);		
+		    	    
 		    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
 		    
-		    throw e;
+		    throw Exception(EXLOC, Chain("Data page lock error"), e);
 		}
 		
 		if ( void* p = _bp.getFirstEntry())
-		{
-		    
-		    dp.setFileId(_fileId);
+		{		    
 		    dp.setPageId(_pageId);
-		    
+		    dp.setOffset(_bp.getEntryPos());		    
 		    len = _bp.getEntryLen();
-		    dp.setOffset(_bp.getEntryPos());
-
 		    return p;
 		}
 		else
 		{
-		    _pLockHandle->unlockData(_type, _lockId);    
-		    _lockId = 0;
-		    
-		    _fileId = _bp.getNextFileId();
 		    _pageId = _bp.getNextPageId();
-		    
+
+		    // keep last page in sync ?
+		    if ( ! ( _lastPageSync && _pageId == 0 ) )
+		    {
+			_pLockHandle->unlockData(_type, _lockId);    
+			_lockId = 0;
+		    }
+		    		   		    
 		    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
 		}
 	    }
@@ -166,53 +157,48 @@ void* CegoObjectCursor::getFirst(int& len, CegoDataPointer& dp)
     catch ( Exception e)
     {
 	abort();
-	throw e;			    
+	throw Exception(EXLOC, Chain("Cannot get first entry"), e);
     }
 }
 
 void* CegoObjectCursor::getNext(int& len, CegoDataPointer& dp)
 {
-    
     if ( _isEOC )
 	return 0;
     
     try
     {
-	
 	void* p = _bp.getNextEntry();    
 	if ( p )
 	{
-	    
-	    dp.setFileId(_fileId);
-	    dp.setPageId(_pageId);
-	    
+	    dp.setPageId(_pageId);	    
+	    dp.setOffset(_bp.getEntryPos());	    
 	    len = _bp.getEntryLen();
-	    dp.setOffset(_bp.getEntryPos());
-	    
 	    return p;
 	}
 	else
 	{
-	    
-	    _pLockHandle->unlockData(_type, _lockId);    
-	    _lockId = 0;
-	    
-	    _fileId = _bp.getNextFileId();
 	    _pageId = _bp.getNextPageId();
+
+	    // keep last page in sync ?
+	    if ( ! ( _lastPageSync && _pageId == 0 ) )
+	    {
+		_pLockHandle->unlockData(_type, _lockId);    
+		_lockId = 0;
+	    }
 	    
 	    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
 	    
-	    while ( ! ( _fileId == 0 && _pageId == 0 ) )
-	    {
-		
+	    while ( ! ( _pageId == 0 ) )
+	    {	
 		CegoBufferPage nbp;
-		_pBufPool->bufferFix(nbp, _tabSetId, _fileId, _pageId, CegoBufferPool::SYNC, _pLockHandle);
+		_pBufPool->bufferFix(nbp, _tabSetId, _pageId, CegoBufferPool::SYNC, _pLockHandle);
 		
 		_bp = nbp;
 		
 		try
 		{
-		    _lockId = _pLockHandle->lockData(_type, _fileId, _pageId, CegoLockHandler::READ);
+		    _lockId = _pLockHandle->lockData(_type, _pageId, CegoLockHandler::READ);
 		}
 		catch ( Exception e )
 		{
@@ -220,32 +206,31 @@ void* CegoObjectCursor::getNext(int& len, CegoDataPointer& dp)
 		    
 		    Chain msg;
 		    e.pop(msg);
-		    _pBufPool->log(_modId, Logger::LOGERR, Chain("Data page lock error for fileId=") 
-				   + Chain(_fileId) + Chain(" pageId=") + Chain(_pageId) + Chain(" : ") +  msg);			    
+		    _pBufPool->log(_modId, Logger::LOGERR, Chain("Data page lock error for pageId=") + Chain(_pageId) + Chain(" : ") +  msg);			    
 		    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
+
+		    throw Exception(EXLOC, Chain("Data page lock error"), e);
 		    
-		    throw e;
 		}
 		
 		if ( void* p = _bp.getFirstEntry())
-		{
-		    
-		    dp.setFileId(_fileId);
+		{	    
 		    dp.setPageId(_pageId);
-		    
+		    dp.setOffset(_bp.getEntryPos());		    
 		    len = _bp.getEntryLen();
-		    dp.setOffset(_bp.getEntryPos());
-
 		    return p;
 		}
 		else
 		{
-		    _pLockHandle->unlockData(_type, _lockId);    
-		    _lockId = 0;
-		    
-		    _fileId = _bp.getNextFileId();
 		    _pageId = _bp.getNextPageId();
-			
+		    
+		    // keep last page in sync ?
+		    if ( ! ( _lastPageSync && _pageId == 0 ) )
+		    {
+			_pLockHandle->unlockData(_type, _lockId);    
+			_lockId = 0;
+		    }
+		    
 		    _pBufPool->bufferUnfix(_bp, false, _pLockHandle);
 		}
 	    }
@@ -256,7 +241,7 @@ void* CegoObjectCursor::getNext(int& len, CegoDataPointer& dp)
     catch ( Exception e)
     {	    	    
 	abort();
-	throw e;
+	throw Exception(EXLOC, Chain("Cannot get next entry"), e);
     }
 }
 
@@ -279,6 +264,5 @@ void CegoObjectCursor::reset()
 {
     abort();
     _isEOC = false;
-    _fileId = _startFileId;
     _pageId = _startPageId;
 }
