@@ -60,13 +60,15 @@ void CegoObjectManager::createTableObject(CegoTableObject& tableObject)
     PageIdType dataPageId = 0;
     
     try
-    {   
+    {
+	/*
 	CegoBufferPool::FixMode lockMode = CegoBufferPool::SYNC;
 	
 	if ( tableObject.getType() == CegoObject::SYSTEM )
 	{
 	    lockMode = CegoBufferPool::PERSISTENT;
 	}
+	*/
 	
 	if ( tableObjectExists(tableObject.getTabSetId(), tableObject.getName()) )
 	{
@@ -1087,7 +1089,7 @@ void CegoObjectManager::getObjectList(int tabSetId, CegoObject::ObjectType type,
 
 	int maxPos = TABMNG_HASHSIZE;
 	
-	for ( PageIdType hashPos = 0 ; hashPos < maxPos; hashPos++ )
+	for ( PageIdType hashPos = 0 ; hashPos < (PageIdType)maxPos; hashPos++ )
 	{	    
 	    PageIdType pageId = pageOffset + hashPos;
 	    	    
@@ -1191,7 +1193,7 @@ void CegoObjectManager::getObjectListByTable(int tabSetId, const Chain& tabName,
 
 	int maxPos = TABMNG_HASHSIZE;
 	
-	for ( PageIdType hashPos = 0; hashPos < maxPos; hashPos++ )
+	for ( PageIdType hashPos = 0; hashPos < (PageIdType)maxPos; hashPos++ )
 	{	    
 	    PageIdType pageId = pageOffset + hashPos;
 	    
