@@ -446,7 +446,7 @@ Chain CegoOutput::formatCell(int i, const Chain& s, int maxLen, bool printSep)
     if ( _format.length() < 2 ) // _format == Chain() )
     {
 	Chain normString;
-	if ( s.length() - 1  > maxLen )
+	if ( (int)s.length() - 1  > maxLen )
 	    normString = s.subChain(1, maxLen - 3 ) + Chain("...");
 	else
 	    normString = s;
@@ -461,7 +461,7 @@ Chain CegoOutput::formatCell(int i, const Chain& s, int maxLen, bool printSep)
 	if ( _format[i] == 'l' )
 	{	    
 	    Chain normString;
-	    if ( s.length() - 1  > maxLen )
+	    if ( (int)s.length() - 1  > maxLen )
 		normString = s.subChain(1, maxLen - 3 ) + Chain("...");
 	    else
 		normString = s;
@@ -474,7 +474,7 @@ Chain CegoOutput::formatCell(int i, const Chain& s, int maxLen, bool printSep)
 	else if ( _format[i] == 'r' )
 	{   
 	    Chain normString;
-	    if ( s.length() - 1  > maxLen )
+	    if ( (int)s.length() - 1  > maxLen )
 		normString = s.subChain(1, maxLen - 3 ) + Chain("...");
 	    else
 		normString = s;
@@ -492,7 +492,7 @@ Chain CegoOutput::formatCell(int i, const Chain& s, int maxLen, bool printSep)
 	    while ( lineTok.nextToken(line) )
 	    {
 		Chain normString;
-		if ( line.length() - 1  > maxLen )
+		if ( (int)line.length() - 1  > maxLen )
 		    normString = line.subChain(1, maxLen - 3 ) + Chain("...");
 		else
 		    normString = line;
