@@ -532,16 +532,19 @@ bool CegoPredicate::isChecked() const
 
 bool CegoPredicate::isCursorPred() const
 {
-
+    bool isPred = false;
+    
     switch (_mode )
     {
     case CegoPredicate::CONDITION:
     {
-	return _pC->isCursorPred();	
+	isPred = _pC->isCursorPred();
+	break;
     }
     case CegoPredicate::NOTPRED:
     {
-	return _pNotPred->isCursorPred();
+	isPred = _pNotPred->isCursorPred();
+	break;
     }
     case CegoPredicate::EXPRCOMP:
     case CegoPredicate::BETWEEN:
@@ -554,16 +557,19 @@ bool CegoPredicate::isCursorPred() const
     case CegoPredicate::ISNCLIKE:
     case CegoPredicate::ISNOTNCLIKE:
     {
-	return true;
+	isPred = true;
+	break;
     }
     case CegoPredicate::EXISTSCOMP:
     case CegoPredicate::INSUB:
     case CegoPredicate::NOTINSUB:
     case CegoPredicate::NOTIN:
     {
-	return false;
+	isPred = false;
+	break;
     }
-    }    
+    }
+    return isPred;
 }
 
 bool CegoPredicate::prioOnJoin() const
@@ -1559,8 +1565,7 @@ CegoFieldValue CegoPredicate::getExprOnlyValue() const
 
 CegoPredicate* CegoPredicate::map(const Chain& viewAlias, ListT<CegoExpr*> exprList) const
 {
-    CegoPredicate* pMap;
-    
+   
     switch (_mode )
     {
     case CegoPredicate::CONDITION:
@@ -1795,9 +1800,7 @@ CegoPredicate* CegoPredicate::getReduced(const Chain& tableAlias) const
 }
 
 CegoPredicate* CegoPredicate::getReduced(const ListT<Chain>& aliasList) const
-{
-    CegoPredicate* pReduced;
-    
+{    
     switch (_mode )
     {
     case CegoPredicate::CONDITION:
@@ -1805,7 +1808,7 @@ CegoPredicate* CegoPredicate::getReduced(const ListT<Chain>& aliasList) const
 	CegoPredicate* pLeft = 0;
 	CegoPredicate* pRight = 0;
 
-	bool reduceOk=true;
+	
 	if ( _pC->Left() )
 	{
 	    pLeft = _pC->Left()->getReduced(aliasList);
@@ -2560,7 +2563,7 @@ Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
 	}
 	
 	Chain addIndent;
-	for ( int i=1; i<s.length(); i++ )
+	for ( int i=1; i < (int)s.length(); i++ )
 	    addIndent += Chain(" ");
 	
 	s +=  _pExpr2->toChain(defTabSetId, indent + addIndent);
@@ -2641,7 +2644,7 @@ Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
 	s += Chain(" in ( ");
 
 	Chain addIndent;
-	for ( int i=1; i<s.length(); i++ )
+	for ( int i=1; i < (int)s.length(); i++ )
 	    addIndent += Chain(" ");
 
 	s += _pSelect->toChain(defTabSetId, indent + addIndent) + Chain(" )");   
@@ -2653,7 +2656,7 @@ Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
 	s += Chain(" not in ( ");
 
 	Chain addIndent;
-	for ( int i=1; i<s.length(); i++ )
+	for ( int i=1; i < (int)s.length(); i++ )
 	    addIndent += Chain(" ");
 
 	s += _pSelect->toChain(defTabSetId, indent + addIndent) + Chain(" )");   
