@@ -45,8 +45,8 @@ public:
     void decode(char *buf);
     const Chain& getProcText() const;
     void setEmpty();
-    Chain toChain() const;    
-    Chain getFormatted() const;
+
+    Chain getInfo() const;
     
     CegoProcObject& operator = ( const CegoProcObject& oe);
     bool operator == ( const CegoProcObject& oe);
@@ -55,7 +55,6 @@ private:
 
     Chain _procText;
 
-    Chain fill(const Chain& s, int num) const;
 };
 #endif
 
