@@ -1,12 +1,12 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                         
 // CegoProcReturnStmt.cc  
-// ---------------------                                                     
+// ---------------------
 // Cego procedure return statement implementation
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -30,12 +30,14 @@
 CegoProcReturnStmt::CegoProcReturnStmt(CegoProcBlock *pBlock) : CegoProcStmt(pBlock)
 {
     _pExpr = 0;
+    _pBlock = pBlock;
 }
 
 CegoProcReturnStmt::CegoProcReturnStmt(CegoExpr *pExpr,
 				       CegoProcBlock *pBlock) : CegoProcStmt(pBlock)
 {
     _pExpr = pExpr;
+    _pBlock = pBlock;
 }
 
 CegoProcReturnStmt::~CegoProcReturnStmt()  
@@ -48,18 +50,22 @@ CegoException CegoProcReturnStmt::execute()
 {
     if ( _pExpr )
     {
-	_pExpr->setBlock(getParentBlock());
-	getParentBlock()->setRetVal(_pExpr->evalFieldValue());
+	getParentBlock()->setRetVal(_pExpr->evalFieldValue(0, getParentBlock()));
     }
     return RETURN_EXCEP;
 }
 
-Chain CegoProcReturnStmt::toChain(const Chain& indent) const
+void CegoProcReturnStmt::cleanUp()
+{
+    _pExpr->cleanUp();
+}
+
+Chain CegoProcReturnStmt::toChain(int defTabSetId, const Chain& indent) const
 {
     Chain s;
     s = indent + Chain("return");
     if ( _pExpr )
-	s += Chain(" ") + _pExpr->toChain();
+	s += Chain(" ") + _pExpr->toChain(defTabSetId);
     return s;
 }
 
@@ -67,3 +73,16 @@ Chain CegoProcReturnStmt::dbFormat(CegoDatabaseFormater *pForm) const
 {
     return pForm->formatProcReturnStmt(_pExpr);
 }
+
+bool CegoProcReturnStmt::isStatic() const
+{
+    try
+    {
+	_pExpr->getId(_pBlock);
+	return true;
+    }
+    catch ( Exception e )
+    {
+	return false;
+    }
+}
