@@ -8,7 +8,7 @@
 //
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -30,32 +30,29 @@ class CegoDatabaseFormater;
 
 class CegoProcVar {
 
- public:
-
+public:
+    
     enum VarType { INVAR, OUTVAR, BLOCKVAR };
 
     CegoProcVar();
     CegoProcVar(const Chain& varName);
-    CegoProcVar(const Chain& varName, VarType paramType, CegoDataType dt, int dtlen, const CegoFieldValue& fv);
+    CegoProcVar(const Chain& varName, VarType paramType, CegoDataType dt, int dtlen, int dtdim, const CegoFieldValue& fv);
     ~CegoProcVar();
     
     void setName(const Chain& name);
     const Chain& getName() const;
-    
     void setVarType(VarType type);
     VarType getVarType() const;
-
     CegoDataType getType() const;
     int getLength() const;
-
+    int getDim() const;
     void setValue(const CegoFieldValue& fv);
     const CegoFieldValue& getValue() const;
+    Chain toChain() const;
+    Chain dbFormat(CegoDatabaseFormater *pForm) const;
 
     CegoProcVar& operator = ( const CegoProcVar& pp);
     bool operator == ( const CegoProcVar& pp);
-
-    Chain toChain() const;
-    Chain dbFormat(CegoDatabaseFormater *pForm) const;
     friend ostream& operator << (ostream& s, const CegoProcVar& pp);
     
 private:
@@ -64,8 +61,7 @@ private:
     VarType _paramType;
     CegoDataType _dt;
     int _dtlen;
+    int _dtdim;
     CegoFieldValue _fv;
-    
 };
-
 #endif
