@@ -528,8 +528,8 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::evalAttrCond(CegoAttrCond& ac,
 				
 				if ( (Chain)pInAttrDesc->getTableName() == (Chain)pFB->getTableName() ||
 				     (Chain)pInAttrDesc->getTableName() == (Chain)pFB->getTableAlias() ||
-				     pInAttrDesc->getTableName() == Chain()
-				     && (Chain)pInAttrDesc->getAttrName() == (Chain)pFB->getAttrName())
+				     ( pInAttrDesc->getTableName() == Chain()
+				       && (Chain)pInAttrDesc->getAttrName() == (Chain)pFB->getAttrName()) )
 				{				
 				    ac.add( CegoAttrComp(tabAlias, 
 							 attrName,
@@ -2066,7 +2066,7 @@ Chain CegoQueryHelper::skipComment(Chain& line)
     bool stringMode=false;
     bool commentFound=false;
     
-    while ( pos < line.length() && commentFound == false)
+    while ( pos < (int)line.length() && commentFound == false)
     {
 	if ( line[pos] == '\''  )
 	{
@@ -2083,7 +2083,7 @@ Chain CegoQueryHelper::skipComment(Chain& line)
 	    }
 	}
 	
-	if ( pos < line.length() -2 )
+	if ( pos < (int)line.length() -2 )
 	{
 	    if ( line[pos] == '-' && line[pos+1] == '-' && stringMode == false)
 	    {
@@ -2111,7 +2111,7 @@ bool CegoQueryHelper::hasOpenString(Chain& line)
 {
     int pos=0;
     bool stringMode=false;
-    while ( pos < line.length())
+    while ( pos < (int)line.length())
     {
 	if ( line[pos] == '\'' )
 	{
