@@ -945,7 +945,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 			pF = jfl.Next();
 		    }
 
-		    if ( _pCache->getMaxSize() > _cacheEntrySize )
+		    if ( _pCache->getMaxSize() > (int)_cacheEntrySize )
 		    {
 			_pCacheList->Insert(staticFieldList);
 		    }
@@ -983,7 +983,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 			pF = jfl.Next();
 		    }
 
-		    if ( _pCache->getMaxSize() > _cacheEntrySize )
+		    if ( _pCache->getMaxSize() > (int)_cacheEntrySize )
 		    {
 			_pCacheList->Insert(staticFieldList);
 		    }
@@ -1529,7 +1529,7 @@ bool CegoSelect::nextResultTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
     }
     case PLAIN:
     case AGGREGATION:
-    {
+    {	
 	return nextJoinTuple(jfl, ofl);
     }
     case GROUPING:
@@ -1614,10 +1614,7 @@ bool CegoSelect::nextGroupedTuple(ListT<CegoField>& jfl)
 	if ( _pHavingPred )
 	{
 	    while ( _pGroupCursor->getNext(jfl) )
-	    {
-		ListT<CegoField>** flArray = 0;
-		ListT<CegoField>* flStaticArray[TABMNG_MAXJOINLEVEL];
-
+	    {	       
 		ListT<CegoField>* fla[2];
 		
 		fla[0]=&jfl;
@@ -1737,7 +1734,7 @@ bool CegoSelect::nextGroupedTuple(ListT<CegoField>& jfl)
 }
 
 bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
-{
+{    
     if ( _pGTM == 0 )
 	throw Exception(EXLOC, "No tablemanager set");
     
@@ -1838,7 +1835,9 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 #ifdef CGDEBUG	    
 		_pDBMng->log(_modId, Logger::DEBUG, Chain("Retrieving first tuple from cursor ..."));
 #endif
-		moreTuple = _pTC[_joinLevel]->nextTuple(_joinBuf, _joinSize, _joinList[_joinLevel]->getSubCOList().Size());		
+		
+		moreTuple = _pTC[_joinLevel]->nextTuple(_joinBuf, _joinSize, _joinList[_joinLevel]->getSubCOList().Size());
+
 #ifdef CGDEBUG
 		if ( moreTuple )
 		    _pDBMng->log(_modId, Logger::DEBUG, Chain("Tuple retrieved"));
@@ -1930,9 +1929,6 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 
 	    pPred = _conjunctionList.Next();
 	}
-
-
-
 	
 	if ( checkPred )
 	{	    
@@ -2590,7 +2586,7 @@ void CegoSelect::buildJoinRefs()
     CegoContentObject** pCO = _joinList.First();
     
     while ( pCO )
-    {       	
+    {	
 	// check for all subCO
 	CegoContentObject **pSubCO = (*pCO)->getSubCOList().First();
 	while ( pSubCO )
@@ -3557,7 +3553,7 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	
 	pBuf += len;
 	i += len;
-	
+
 	_coList.Insert( pCO );	
     }
 
