@@ -8,7 +8,7 @@
 //
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -33,35 +33,33 @@
 #include "CegoDecodableObject.h"
 
 class CegoSerial {
-
- public:
-
-    CegoSerial(NetHandler *pN);
+    
+public:
+    
+    CegoSerial(NetHandler *pN, bool isFast);
     ~CegoSerial();
     
     void reset();
     bool isReset() const;
-
     void writeChain(const Chain& s);
-    void writeSchema(const ListT<CegoField>& schema);
-    void writeObject(const CegoDecodableObject& oe);
     void writeRow(const ListT<CegoField>& fl);
     void writeRow(const ListT<CegoFieldValue>& fvl);
-
+    void writeSchema(const ListT<CegoField>& schema);
+    void writeObject(const CegoDecodableObject& oe);
     Chain readChain();
+    void readRow(const ListT<CegoField>& schema, ListT<CegoFieldValue>& fvl);    
     ListT<CegoField> readSchema();
-    ListT<CegoFieldValue> readRow(const ListT<CegoField>& schema);
-
+    int numWritten() const;
     int numAhead() const;
-
     Chain toChain() const;
 
     friend ostream& operator << (ostream& s, const CegoSerial& ser);
 
- private:
-
+private:
+    
+    bool _isFast;
+    char*  _pFastCursor;
     NetHandler* _pN;
     Tokenizer* _pTok;
 };
-
 #endif
