@@ -197,7 +197,7 @@ Chain CegoTableObject::getId(CegoProcBlock *pBlock) const
 
 Chain CegoTableObject::toChain(int defTabSetId) const
 {
-    if ( defTabSetId == getTabSetId() && defTabSetId != 0 )
+    if ( ( defTabSetId == getTabSetId() && defTabSetId != 0 ) || defTabSetId == 0 )
 	return getTabName() + Chain(" ") + getName();
     else
 	return getTabName() + Chain("@") + getTableSet() + Chain(" ") + getName();
