@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -37,52 +37,43 @@ class CegoTableManager;
 
 class CegoTransactionManager {
     
- public:
+public:
 
     CegoTransactionManager(CegoTableManager* pTM);
     ~CegoTransactionManager();
        
     void release(int tabSetId);
-
-    void initLock(int tabSetId);
     void reorgSystemSpace(int tabSetId);
-
     void recordUpdate(int tabSetId, unsigned long long tid, const CegoDataPointer& dp );
     void commitUpdate(int tabSetId, const Chain& idxName, const CegoObject::ObjectType idxType, unsigned long long tid, bool doAppend);
-
-    void getRBDataPtr(int tabSetId, unsigned long long tid, int fileId, int pageId, int offset, int& rbfileId, int& rbpageId, int& rboffset);
-
-    void newRBEntry(int tabSetId, unsigned long long tid, int fileId, int pageId, int offset, const Chain& tableName);
-    
+    void abortUpdate(int tabSetId, unsigned long long tid);
+    void getRBDataPtr(int tabSetId, unsigned long long tid, PageIdType pageId, int offset, int& rbfileId, int& rbpageId, int& rboffset);
+    void newRBEntry(int tabSetId, unsigned long long tid, PageIdType pageId, int offset, const Chain& tableName);
     unsigned long long commitTransaction(int tabSetId, unsigned long long tid);
-
+    void getCrashAffectedTables(int tabSetId, SetT<Chain>& tableList);
     void getTransactionAffectedTables(int tabSetId, unsigned long long tid, SetT<Chain>& tableList);
-
+    bool hasOpenTransaction(int tabSetId, const Chain& tableName) const;
     void finishOpenTransaction(int tabSetId);
     unsigned long long rollbackTransaction(int tabSetId, unsigned long long tid);
-    
     void getTransactionInfo(int tabSetId, const Chain& rbo, int& numop);
      
- private:
-
-    unsigned long long doCommit(int tabSetId, const Chain& rbo);
-    unsigned long long doRollback(int tabSetId, const Chain& rbo);
-
+private:
+    
     class TAEntry {
 	
     public:
 	
 	TAEntry();
 	TAEntry(const unsigned long long tid);
-	TAEntry(const unsigned long long tid, const CegoBufferPage& bp, const CegoTableObject& oe);
+	TAEntry(const unsigned long long tid,
+		// const CegoBufferPage& bp,
+		const CegoTableObject& oe);
 	~TAEntry();
-
+	
 	const unsigned long long getTid() const;
-
-	CegoBufferPage& getBufferPage();
+	
 	CegoTableObject& getTableObject();
-	CegoDataPointer getDataPointer();
-
+	
 	TAEntry& operator = ( const TAEntry& t);
         bool operator == ( const TAEntry& t);
 	
@@ -95,23 +86,20 @@ class CegoTransactionManager {
     private:
 
 	unsigned long long _tid;
-	CegoBufferPage _bp;
 	CegoTableObject _oe;
     };
 
+    unsigned long long doCommit(int tabSetId, const Chain& rbo);
+    unsigned long long doRollback(int tabSetId, const Chain& rbo);
 
     ListT<TAEntry> _taList;
     ListT<TAEntry> _udList;
-
     CegoDatabaseManager *_pDBMng;
-    CegoTableManager* _pTM;
-
+    CegoTableManager* _pTabMng;
     ListT<CegoField> _updSchema;
     ListT<CegoField> _rbcatSchema;
-
     CegoQueryHelper _qh;
 
     unsigned long _modId;
 };
-
 #endif
