@@ -116,7 +116,7 @@ Chain CegoViewObject::getId(CegoProcBlock *pBlock) const
 
 Chain CegoViewObject::toChain(int defTabSetId) const
 {
-    if ( defTabSetId == getTabSetId() && defTabSetId != 0)
+    if ( ( defTabSetId == getTabSetId() && defTabSetId != 0 ) || defTabSetId == 0 )
 	return getTabName() + Chain(" ") + getName();
     else
 	return getTabName() + Chain("@") + getTableSet() + Chain(" ") + getName();
