@@ -6,7 +6,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -36,7 +36,6 @@ CegoXMLHelper::~CegoXMLHelper()
 
 void CegoXMLHelper::setColInfo(Element* pColElement, CegoField *pF )
 {
-
     pColElement->setAttribute(XML_COLNAME_ATTR, pF->getAttrName());
     if ( pF->isNullable() )
 	pColElement->setAttribute(XML_COLNULLABLE_ATTR, XML_TRUE_VALUE);
@@ -46,6 +45,8 @@ void CegoXMLHelper::setColInfo(Element* pColElement, CegoField *pF )
     if ( pF->getValue().getValue() )
 	pColElement->setAttribute(XML_COLDEFVALUE_ATTR, pF->getValue().valAsChain() );
     
+    pColElement->setAttribute(XML_COLTYPEID_ATTR, Chain(pF->getType()));
+    
     if ( pF->getType() == VARCHAR_TYPE )
     {
 	pColElement->setAttribute(XML_COLTYPE_ATTR, XML_STRING_VALUE);
@@ -81,11 +82,6 @@ void CegoXMLHelper::setColInfo(Element* pColElement, CegoField *pF )
 	pColElement->setAttribute(XML_COLTYPE_ATTR, XML_DECIMAL_VALUE);
 	pColElement->setAttribute(XML_JAVATYPE_ATTR, Chain(CEGO_JAVATYPE_MAP[DECIMAL_TYPE]));
     }
-    else if ( pF->getType() == FIXED_TYPE )
-    {
-	pColElement->setAttribute(XML_COLTYPE_ATTR, XML_FIXED_VALUE);
-	pColElement->setAttribute(XML_JAVATYPE_ATTR, Chain(CEGO_JAVATYPE_MAP[FIXED_TYPE]));
-    }
     else if ( pF->getType() == FLOAT_TYPE )
     {
 	pColElement->setAttribute(XML_COLTYPE_ATTR, XML_FLOAT_VALUE);
@@ -113,6 +109,7 @@ void CegoXMLHelper::setColInfo(Element* pColElement, CegoField *pF )
     }
     
     pColElement->setAttribute(XML_COLSIZE_ATTR, Chain(pF->getLength()));
+    pColElement->setAttribute(XML_COLDIM_ATTR, Chain(pF->getDim()));
 }
 
 void CegoXMLHelper::getColInfo(const Chain& objName, Element* pColElement, CegoField &f)
@@ -120,6 +117,7 @@ void CegoXMLHelper::getColInfo(const Chain& objName, Element* pColElement, CegoF
     Chain colName = pColElement->getAttributeValue(XML_COLNAME_ATTR);
     Chain colType = pColElement->getAttributeValue(XML_COLTYPE_ATTR);
     Chain colSize = pColElement->getAttributeValue(XML_COLSIZE_ATTR);
+    Chain colDim = pColElement->getAttributeValue(XML_COLDIM_ATTR);
     Chain colNullable = pColElement->getAttributeValue(XML_COLNULLABLE_ATTR);
     Chain colDefValue = pColElement->getAttributeValue(XML_COLDEFVALUE_ATTR);
 
@@ -129,18 +127,16 @@ void CegoXMLHelper::getColInfo(const Chain& objName, Element* pColElement, CegoF
     else
 	isNullable = false;
 
-    CegoTypeConverter tc;
-    CegoDataType dataType = tc.getTypeId(colType);
+    CegoDataType dataType = CegoTypeConverter::getTypeId(colType);
     
     CegoFieldValue defValue;
-    if ( colDefValue != Chain("") )
+    if ( colDefValue != Chain() )
     {
 	defValue = CegoFieldValue(dataType, colDefValue);
     }
     
     if ( dataType != NULL_TYPE )
-	f = CegoField(CegoField(objName, objName, colName, dataType, colSize.asInteger(), defValue, isNullable));		
+	f = CegoField(CegoField(objName, objName, colName, dataType, colSize.asInteger(), colDim.asInteger(), defValue, isNullable));
     else
 	f = CegoField(objName, colName);
-
 }
