@@ -927,7 +927,7 @@ extern "C" {
 		return -1;
 	    }
 	    
-	    if ( cgblob->len < blob.getSize() )
+	    if ( cgblob->len < (int)blob.getSize() )
 	    {
 		cgblob->buf = (unsigned char*)realloc( cgblob->buf, blob.getSize());
 		cgblob->len = blob.getSize();
@@ -991,7 +991,7 @@ extern "C" {
 		strcpy(cgerrmsg, (char*)msg);		
 		return -1;
 	    }
-	    if ( cgclob->len < clob.getSize() )
+	    if ( cgclob->len < (int)clob.getSize() )
 	    {
 		cgclob->buf = (char*)realloc( cgclob->buf, clob.getSize());
 		cgclob->len = clob.getSize();
@@ -1172,7 +1172,7 @@ static void updateModLog(CegoModule* pModule)
 	tok.nextToken(module);
 	tok.nextToken(levelString);
 
-	Logger::LogLevel level;
+	Logger::LogLevel level = Logger::NONE;
 	
 	if ( levelString == Chain("NOTICE") )
 	    level = Logger::NOTICE;
